# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/proto/delphi_esr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/proto/delphi_esr.proto',
  package='apollo.drivers',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/drivers/proto/delphi_esr.proto\x12\x0e\x61pollo.drivers\x1a!modules/common/proto/header.proto\"\xfc\x01\n\x0f\x45sr_status9_5e8\x12\x1c\n\x14\x63\x61n_tx_path_id_acc_3\x18\x01 \x01(\x05\x12\x1c\n\x14\x63\x61n_tx_path_id_acc_2\x18\x02 \x01(\x05\x12%\n\x1d\x63\x61n_tx_filtered_xohp_acc_cipv\x18\x03 \x01(\x01\x12$\n\x1c\x63\x61n_tx_water_spray_target_id\x18\x04 \x01(\x05\x12\"\n\x1a\x63\x61n_tx_serial_num_3rd_byte\x18\x05 \x01(\x05\x12\x1d\n\x15\x63\x61n_tx_sideslip_angle\x18\x06 \x01(\x01\x12\x1d\n\x15\x63\x61n_tx_avg_pwr_cwblkg\x18\x07 \x01(\x05\"\x9a\x11\n\x0f\x45sr_status6_5e5\x12&\n\x1e\x63\x61n_tx_sw_version_dsp_3rd_byte\x18\x01 \x01(\x05\x12h\n\x1d\x63\x61n_tx_vertical_align_updated\x18\x02 \x01(\x0e\x32\x41.apollo.drivers.Esr_status6_5e5.Can_tx_vertical_align_updatedType\x12$\n\x1c\x63\x61n_tx_vertical_misalignment\x18\x03 \x01(\x01\x12&\n\x1e\x63\x61n_tx_serv_align_updates_done\x18\x04 \x01(\x05\x12T\n\x13\x63\x61n_tx_found_target\x18\x05 \x01(\x0e\x32\x37.apollo.drivers.Esr_status6_5e5.Can_tx_found_targetType\x12#\n\x1b\x63\x61n_tx_factory_misalignment\x18\x06 \x01(\x01\x12h\n\x1d\x63\x61n_tx_factory_align_status_2\x18\x07 \x01(\x0e\x32\x41.apollo.drivers.Esr_status6_5e5.Can_tx_factory_align_status_2Type\x12h\n\x1d\x63\x61n_tx_factory_align_status_1\x18\x08 \x01(\x0e\x32\x41.apollo.drivers.Esr_status6_5e5.Can_tx_factory_align_status_1Type\x12\x64\n\x1b\x63\x61n_tx_recommend_unconverge\x18\t \x01(\x0e\x32?.apollo.drivers.Esr_status6_5e5.Can_tx_recommend_unconvergeType\x12\x1c\n\x14\x63\x61n_tx_wave_diff_a2d\x18\n \x01(\x05\x12^\n\x18\x63\x61n_tx_system_power_mode\x18\x0b \x01(\x0e\x32<.apollo.drivers.Esr_status6_5e5.Can_tx_system_power_modeType\x12\x1d\n\x15\x63\x61n_tx_supply_n5v_a2d\x18\x0c \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_supply_1p8v_a2d\x18\r \x01(\x05\"}\n!Can_tx_vertical_align_updatedType\x12-\n)CAN_TX_VERTICAL_ALIGN_UPDATED_NOT_UPDATED\x10\x00\x12)\n%CAN_TX_VERTICAL_ALIGN_UPDATED_UPDATED\x10\x01\"[\n\x17\x43\x61n_tx_found_targetType\x12!\n\x1d\x43\x41N_TX_FOUND_TARGET_NOT_FOUND\x10\x00\x12\x1d\n\x19\x43\x41N_TX_FOUND_TARGET_FOUND\x10\x01\"\xbb\x02\n!Can_tx_factory_align_status_2Type\x12%\n!CAN_TX_FACTORY_ALIGN_STATUS_2_OFF\x10\x00\x12&\n\"CAN_TX_FACTORY_ALIGN_STATUS_2_BUSY\x10\x01\x12)\n%CAN_TX_FACTORY_ALIGN_STATUS_2_SUCCESS\x10\x02\x12\x30\n,CAN_TX_FACTORY_ALIGN_STATUS_2_FAIL_NO_TARGET\x10\x03\x12\x34\n0CAN_TX_FACTORY_ALIGN_STATUS_2_FAIL_DEV_TOO_LARGE\x10\x04\x12\x34\n0CAN_TX_FACTORY_ALIGN_STATUS_2_FAIL_VAR_TOO_LARGE\x10\x05\"\xbb\x02\n!Can_tx_factory_align_status_1Type\x12%\n!CAN_TX_FACTORY_ALIGN_STATUS_1_OFF\x10\x00\x12&\n\"CAN_TX_FACTORY_ALIGN_STATUS_1_BUSY\x10\x01\x12)\n%CAN_TX_FACTORY_ALIGN_STATUS_1_SUCCESS\x10\x02\x12\x30\n,CAN_TX_FACTORY_ALIGN_STATUS_1_FAIL_NO_TARGET\x10\x03\x12\x34\n0CAN_TX_FACTORY_ALIGN_STATUS_1_FAIL_DEV_TOO_LARGE\x10\x04\x12\x34\n0CAN_TX_FACTORY_ALIGN_STATUS_1_FAIL_VAR_TOO_LARGE\x10\x05\"{\n\x1f\x43\x61n_tx_recommend_unconvergeType\x12-\n)CAN_TX_RECOMMEND_UNCONVERGE_NOT_RECOMMEND\x10\x00\x12)\n%CAN_TX_RECOMMEND_UNCONVERGE_RECOMMEND\x10\x01\"\xdf\x02\n\x1c\x43\x61n_tx_system_power_modeType\x12%\n!CAN_TX_SYSTEM_POWER_MODE_DSP_INIT\x10\x00\x12(\n$CAN_TX_SYSTEM_POWER_MODE_RADIATE_OFF\x10\x01\x12\'\n#CAN_TX_SYSTEM_POWER_MODE_RADIATE_ON\x10\x02\x12)\n%CAN_TX_SYSTEM_POWER_MODE_DSP_SHUTDOWN\x10\x03\x12$\n CAN_TX_SYSTEM_POWER_MODE_DSP_OFF\x10\x04\x12*\n&CAN_TX_SYSTEM_POWER_MODE_HOST_SHUTDOWN\x10\x05\x12!\n\x1d\x43\x41N_TX_SYSTEM_POWER_MODE_TEST\x10\x06\x12%\n!CAN_TX_SYSTEM_POWER_MODE_7INVALID\x10\x07\"\xf7\x01\n\x0f\x45sr_status5_5e4\x12\x1d\n\x15\x63\x61n_tx_supply_10v_a2d\x18\x01 \x01(\x05\x12\x18\n\x10\x63\x61n_tx_temp2_a2d\x18\x02 \x01(\x05\x12\x18\n\x10\x63\x61n_tx_temp1_a2d\x18\x03 \x01(\x05\x12\x19\n\x11\x63\x61n_tx_swbatt_a2d\x18\x04 \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_supply_5vdx_a2d\x18\x05 \x01(\x05\x12\x1d\n\x15\x63\x61n_tx_supply_5va_a2d\x18\x06 \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_supply_3p3v_a2d\x18\x07 \x01(\x05\x12\x17\n\x0f\x63\x61n_tx_ignp_a2d\x18\x08 \x01(\x05\"\xa8\x01\n\x0f\x45sr_status3_4e2\x12\x1d\n\x15\x63\x61n_tx_sw_version_pld\x18\x01 \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_sw_version_host\x18\x02 \x01(\x05\x12\x19\n\x11\x63\x61n_tx_hw_version\x18\x03 \x01(\x05\x12 \n\x18\x63\x61n_tx_interface_version\x18\x04 \x01(\x05\x12\x19\n\x11\x63\x61n_tx_serial_num\x18\x05 \x01(\x05\"\x96\x0b\n\x0f\x45sr_status4_4e3\x12\\\n\x17\x63\x61n_tx_truck_target_det\x18\x01 \x01(\x0e\x32;.apollo.drivers.Esr_status4_4e3.Can_tx_truck_target_detType\x12l\n\x1f\x63\x61n_tx_lr_only_grating_lobe_det\x18\x02 \x01(\x0e\x32\x43.apollo.drivers.Esr_status4_4e3.Can_tx_lr_only_grating_lobe_detType\x12^\n\x18\x63\x61n_tx_sidelobe_blockage\x18\x03 \x01(\x0e\x32<.apollo.drivers.Esr_status4_4e3.Can_tx_sidelobe_blockageType\x12\\\n\x17\x63\x61n_tx_partial_blockage\x18\x04 \x01(\x0e\x32;.apollo.drivers.Esr_status4_4e3.Can_tx_partial_blockageType\x12\x1f\n\x17\x63\x61n_tx_path_id_acc_stat\x18\x05 \x01(\x05\x12P\n\x11\x63\x61n_tx_mr_lr_mode\x18\x06 \x01(\x0e\x32\x35.apollo.drivers.Esr_status4_4e3.Can_tx_mr_lr_modeType\x12\x1f\n\x17\x63\x61n_tx_auto_align_angle\x18\x07 \x01(\x01\x12\x1e\n\x16\x63\x61n_tx_rolling_count_3\x18\x08 \x01(\x05\x12\x1f\n\x17\x63\x61n_tx_path_id_fcw_stat\x18\t \x01(\x05\x12\x1f\n\x17\x63\x61n_tx_path_id_fcw_move\x18\n \x01(\x05\x12 \n\x18\x63\x61n_tx_path_id_cmbb_stat\x18\x0b \x01(\x05\x12 \n\x18\x63\x61n_tx_path_id_cmbb_move\x18\x0c \x01(\x05\x12\x1a\n\x12\x63\x61n_tx_path_id_acc\x18\r \x01(\x05\"m\n\x1b\x43\x61n_tx_truck_target_detType\x12(\n$CAN_TX_TRUCK_TARGET_DET_NOT_DETECTED\x10\x00\x12$\n CAN_TX_TRUCK_TARGET_DET_DETECTED\x10\x01\"\x85\x01\n#Can_tx_lr_only_grating_lobe_detType\x12\x30\n,CAN_TX_LR_ONLY_GRATING_LOBE_DET_NOT_DETECTED\x10\x00\x12,\n(CAN_TX_LR_ONLY_GRATING_LOBE_DET_DETECTED\x10\x01\"a\n\x1c\x43\x61n_tx_sidelobe_blockageType\x12 \n\x1c\x43\x41N_TX_SIDELOBE_BLOCKAGE_OFF\x10\x00\x12\x1f\n\x1b\x43\x41N_TX_SIDELOBE_BLOCKAGE_ON\x10\x01\"k\n\x1b\x43\x61n_tx_partial_blockageType\x12\'\n#CAN_TX_PARTIAL_BLOCKAGE_NOT_BLOCKED\x10\x00\x12#\n\x1f\x43\x41N_TX_PARTIAL_BLOCKAGE_BLOCKED\x10\x01\"\xdb\x01\n\x15\x43\x61n_tx_mr_lr_modeType\x12\x1e\n\x1a\x43\x41N_TX_MR_LR_MODE_RESERVED\x10\x00\x12\x35\n1CAN_TX_MR_LR_MODE_OUTPUT_ONLY_MEDIUM_RANGE_TRACKS\x10\x01\x12\x33\n/CAN_TX_MR_LR_MODE_OUTPUT_ONLY_LONG_RANGE_TRACKS\x10\x02\x12\x36\n2CAN_TX_MR_LR_MODE_OUTPUT_ALL_MEDIUM_RANGE_AND_LONG\x10\x03\"\xc9\x02\n\x18\x45sr_trackmotionpower_540\x12$\n\x1c\x63\x61n_tx_track_rolling_count_2\x18\x01 \x01(\x08\x12!\n\x19\x63\x61n_tx_track_can_id_group\x18\x02 \x01(\x05\x12W\n\x19\x63\x61n_tx_track_motion_power\x18\x03 \x03(\x0b\x32\x34.apollo.drivers.Esr_trackmotionpower_540.Motionpower\x1a\x8a\x01\n\x0bMotionpower\x12\x1b\n\x13\x63\x61n_tx_track_moving\x18\x01 \x01(\x08\x12 \n\x18\x63\x61n_tx_track_moving_fast\x18\x02 \x01(\x08\x12 \n\x18\x63\x61n_tx_track_moving_slow\x18\x03 \x01(\x08\x12\x1a\n\x12\x63\x61n_tx_track_power\x18\x04 \x01(\x05\"\x89\x01\n\x10\x41\x63m_inst_req_7e0\x12\x13\n\x0b\x63ommand_ctr\x18\x01 \x01(\x05\x12\x14\n\x0c\x63ommand_code\x18\x02 \x01(\x05\x12\x11\n\tcc_word_2\x18\x03 \x01(\x05\x12\x11\n\tcc_word_1\x18\x04 \x01(\x05\x12\x11\n\tcc_byte_2\x18\x05 \x01(\x05\x12\x11\n\tcc_byte_1\x18\x06 \x01(\x05\"\x83\r\n\x0f\x45sr_track01_500\x12h\n\x1d\x63\x61n_tx_track_grouping_changed\x18\x01 \x01(\x0e\x32\x41.apollo.drivers.Esr_track01_500.Can_tx_track_grouping_changedType\x12X\n\x15\x63\x61n_tx_track_oncoming\x18\x02 \x01(\x0e\x32\x39.apollo.drivers.Esr_track01_500.Can_tx_track_oncomingType\x12\x1d\n\x15\x63\x61n_tx_track_lat_rate\x18\x03 \x01(\x01\x12\x62\n\x1a\x63\x61n_tx_track_bridge_object\x18\x04 \x01(\x0e\x32>.apollo.drivers.Esr_track01_500.Can_tx_track_bridge_objectType\x12\x1a\n\x12\x63\x61n_tx_track_width\x18\x05 \x01(\x01\x12T\n\x13\x63\x61n_tx_track_status\x18\x06 \x01(\x0e\x32\x37.apollo.drivers.Esr_track01_500.Can_tx_track_statusType\x12\"\n\x1a\x63\x61n_tx_track_rolling_count\x18\x07 \x01(\x08\x12\x1f\n\x17\x63\x61n_tx_track_range_rate\x18\x08 \x01(\x01\x12 \n\x18\x63\x61n_tx_track_range_accel\x18\t \x01(\x01\x12\x1a\n\x12\x63\x61n_tx_track_range\x18\n \x01(\x01\x12\x64\n\x1b\x63\x61n_tx_track_med_range_mode\x18\x0b \x01(\x0e\x32?.apollo.drivers.Esr_track01_500.Can_tx_track_med_range_modeType\x12\x1a\n\x12\x63\x61n_tx_track_angle\x18\x0c \x01(\x01\"\x8b\x01\n!Can_tx_track_grouping_changedType\x12\x33\n/CAN_TX_TRACK_GROUPING_CHANGED_GROUPINGUNCHANGED\x10\x00\x12\x31\n-CAN_TX_TRACK_GROUPING_CHANGED_GROUPINGCHANGED\x10\x01\"f\n\x19\x43\x61n_tx_track_oncomingType\x12%\n!CAN_TX_TRACK_ONCOMING_NOTONCOMING\x10\x00\x12\"\n\x1e\x43\x41N_TX_TRACK_ONCOMING_ONCOMING\x10\x01\"r\n\x1e\x43\x61n_tx_track_bridge_objectType\x12)\n%CAN_TX_TRACK_BRIDGE_OBJECT_NOT_BRIDGE\x10\x00\x12%\n!CAN_TX_TRACK_BRIDGE_OBJECT_BRIDGE\x10\x01\"\xdf\x02\n\x17\x43\x61n_tx_track_statusType\x12!\n\x1d\x43\x41N_TX_TRACK_STATUS_NO_TARGET\x10\x00\x12\"\n\x1e\x43\x41N_TX_TRACK_STATUS_NEW_TARGET\x10\x01\x12*\n&CAN_TX_TRACK_STATUS_NEW_UPDATED_TARGET\x10\x02\x12&\n\"CAN_TX_TRACK_STATUS_UPDATED_TARGET\x10\x03\x12&\n\"CAN_TX_TRACK_STATUS_COASTED_TARGET\x10\x04\x12%\n!CAN_TX_TRACK_STATUS_MERGED_TARGET\x10\x05\x12.\n*CAN_TX_TRACK_STATUS_INVALID_COASTED_TARGET\x10\x06\x12*\n&CAN_TX_TRACK_STATUS_NEW_COASTED_TARGET\x10\x07\"\xe5\x01\n\x1f\x43\x61n_tx_track_med_range_modeType\x12/\n+CAN_TX_TRACK_MED_RANGE_MODE_NO_MR_LR_UPDATE\x10\x00\x12.\n*CAN_TX_TRACK_MED_RANGE_MODE_MR_UPDATE_ONLY\x10\x01\x12.\n*CAN_TX_TRACK_MED_RANGE_MODE_LR_UPDATE_ONLY\x10\x02\x12\x31\n-CAN_TX_TRACK_MED_RANGE_MODE_BOTH_MR_LR_UPDATE\x10\x03\"\xad\x01\n\x0e\x45sr_valid1_5d0\x12\x1a\n\x12\x63\x61n_tx_valid_lr_sn\x18\x01 \x01(\x05\x12\"\n\x1a\x63\x61n_tx_valid_lr_range_rate\x18\x02 \x01(\x01\x12\x1d\n\x15\x63\x61n_tx_valid_lr_range\x18\x03 \x01(\x01\x12\x1d\n\x15\x63\x61n_tx_valid_lr_power\x18\x04 \x01(\x05\x12\x1d\n\x15\x63\x61n_tx_valid_lr_angle\x18\x05 \x01(\x01\"\xad\x01\n\x0e\x45sr_valid2_5d1\x12\x1a\n\x12\x63\x61n_tx_valid_mr_sn\x18\x01 \x01(\x05\x12\"\n\x1a\x63\x61n_tx_valid_mr_range_rate\x18\x02 \x01(\x01\x12\x1d\n\x15\x63\x61n_tx_valid_mr_range\x18\x03 \x01(\x01\x12\x1d\n\x15\x63\x61n_tx_valid_mr_power\x18\x04 \x01(\x05\x12\x1d\n\x15\x63\x61n_tx_valid_mr_angle\x18\x05 \x01(\x01\"\xa6\x01\n\x11\x41\x63m_inst_resp_7e4\x12\x0e\n\x06\x64\x61ta_7\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x61ta_6\x18\x02 \x01(\x05\x12\x0e\n\x06\x64\x61ta_5\x18\x03 \x01(\x05\x12\x0e\n\x06\x64\x61ta_4\x18\x04 \x01(\x05\x12\x0e\n\x06\x64\x61ta_3\x18\x05 \x01(\x05\x12\x17\n\x0frtn_cmd_counter\x18\x06 \x01(\x05\x12\x1b\n\x13\x63ommand_return_code\x18\x07 \x01(\x05\x12\x0b\n\x03pid\x18\x08 \x01(\x05\"\x9f\x15\n\x0cVehicle2_4f1\x12$\n\x1c\x63\x61n_rx_volvo_short_track_roc\x18\x01 \x01(\x01\x12Y\n\x17\x63\x61n_rx_mr_only_transmit\x18\x02 \x01(\x0e\x32\x38.apollo.drivers.Vehicle2_4f1.Can_rx_mr_only_transmitType\x12Y\n\x17\x63\x61n_rx_lr_only_transmit\x18\x03 \x01(\x0e\x32\x38.apollo.drivers.Vehicle2_4f1.Can_rx_lr_only_transmitType\x12\x1d\n\x15\x63\x61n_rx_high_yaw_angle\x18\x04 \x01(\x05\x12Q\n\x13\x63\x61n_rx_clear_faults\x18\x05 \x01(\x0e\x32\x34.apollo.drivers.Vehicle2_4f1.Can_rx_clear_faultsType\x12\x65\n\x1d\x63\x61n_rx_use_angle_misalignment\x18\x06 \x01(\x0e\x32>.apollo.drivers.Vehicle2_4f1.Can_rx_use_angle_misalignmentType\x12]\n\x19\x63\x61n_rx_turn_signal_status\x18\x07 \x01(\x0e\x32:.apollo.drivers.Vehicle2_4f1.Can_rx_turn_signal_statusType\x12Y\n\x17\x63\x61n_rx_blockage_disable\x18\x08 \x01(\x0e\x32\x38.apollo.drivers.Vehicle2_4f1.Can_rx_blockage_disableType\x12\x65\n\x1d\x63\x61n_rx_vehicle_speed_validity\x18\t \x01(\x0e\x32>.apollo.drivers.Vehicle2_4f1.Can_rx_vehicle_speed_validityType\x12W\n\x16\x63\x61n_rx_mmr_upside_down\x18\n \x01(\x0e\x32\x37.apollo.drivers.Vehicle2_4f1.Can_rx_mmr_upside_downType\x12Q\n\x13\x63\x61n_rx_wiper_status\x18\x0b \x01(\x0e\x32\x34.apollo.drivers.Vehicle2_4f1.Can_rx_wiper_statusType\x12W\n\x16\x63\x61n_rx_raw_data_enable\x18\x0c \x01(\x0e\x32\x37.apollo.drivers.Vehicle2_4f1.Can_rx_raw_data_enableType\x12[\n\x18\x63\x61n_rx_radar_cmd_radiate\x18\r \x01(\x0e\x32\x39.apollo.drivers.Vehicle2_4f1.Can_rx_radar_cmd_radiateType\x12S\n\x14\x63\x61n_rx_grouping_mode\x18\x0e \x01(\x0e\x32\x35.apollo.drivers.Vehicle2_4f1.Can_rx_grouping_modeType\x12\x1d\n\x15\x63\x61n_rx_maximum_tracks\x18\x0f \x01(\x05\x12&\n\x1e\x63\x61n_rx_lateral_mounting_offset\x18\x10 \x01(\x01\x12!\n\x19\x63\x61n_rx_angle_misalignment\x18\x11 \x01(\x01\x12\x1d\n\x15\x63\x61n_rx_scan_index_ack\x18\x12 \x01(\x05\"^\n\x1b\x43\x61n_rx_mr_only_transmitType\x12\x1f\n\x1b\x43\x41N_RX_MR_ONLY_TRANSMIT_OFF\x10\x00\x12\x1e\n\x1a\x43\x41N_RX_MR_ONLY_TRANSMIT_ON\x10\x01\"^\n\x1b\x43\x61n_rx_lr_only_transmitType\x12\x1f\n\x1b\x43\x41N_RX_LR_ONLY_TRANSMIT_OFF\x10\x00\x12\x1e\n\x1a\x43\x41N_RX_LR_ONLY_TRANSMIT_ON\x10\x01\"R\n\x17\x43\x61n_rx_clear_faultsType\x12\x1b\n\x17\x43\x41N_RX_CLEAR_FAULTS_OFF\x10\x00\x12\x1a\n\x16\x43\x41N_RX_CLEAR_FAULTS_ON\x10\x01\"p\n!Can_rx_use_angle_misalignmentType\x12%\n!CAN_RX_USE_ANGLE_MISALIGNMENT_OFF\x10\x00\x12$\n CAN_RX_USE_ANGLE_MISALIGNMENT_ON\x10\x01\"\xb4\x01\n\x1d\x43\x61n_rx_turn_signal_statusType\x12!\n\x1d\x43\x41N_RX_TURN_SIGNAL_STATUS_OFF\x10\x00\x12\"\n\x1e\x43\x41N_RX_TURN_SIGNAL_STATUS_LEFT\x10\x01\x12#\n\x1f\x43\x41N_RX_TURN_SIGNAL_STATUS_RIGHT\x10\x02\x12\'\n#CAN_RX_TURN_SIGNAL_STATUS_INVALID_3\x10\x03\"h\n\x1b\x43\x61n_rx_blockage_disableType\x12#\n\x1f\x43\x41N_RX_BLOCKAGE_DISABLE_ENABLED\x10\x00\x12$\n CAN_RX_BLOCKAGE_DISABLE_DISABLED\x10\x01\"w\n!Can_rx_vehicle_speed_validityType\x12)\n%CAN_RX_VEHICLE_SPEED_VALIDITY_INVALID\x10\x00\x12\'\n#CAN_RX_VEHICLE_SPEED_VALIDITY_VALID\x10\x01\"n\n\x1a\x43\x61n_rx_mmr_upside_downType\x12(\n$CAN_RX_MMR_UPSIDE_DOWN_RIGHT_SIDE_UP\x10\x00\x12&\n\"CAN_RX_MMR_UPSIDE_DOWN_UPSIDE_DOWN\x10\x01\"R\n\x17\x43\x61n_rx_wiper_statusType\x12\x1b\n\x17\x43\x41N_RX_WIPER_STATUS_OFF\x10\x00\x12\x1a\n\x16\x43\x41N_RX_WIPER_STATUS_ON\x10\x01\"a\n\x1a\x43\x61n_rx_raw_data_enableType\x12#\n\x1f\x43\x41N_RX_RAW_DATA_ENABLE_FILTERED\x10\x00\x12\x1e\n\x1a\x43\x41N_RX_RAW_DATA_ENABLE_RAW\x10\x01\"a\n\x1c\x43\x61n_rx_radar_cmd_radiateType\x12 \n\x1c\x43\x41N_RX_RADAR_CMD_RADIATE_OFF\x10\x00\x12\x1f\n\x1b\x43\x41N_RX_RADAR_CMD_RADIATE_ON\x10\x01\"\xce\x01\n\x18\x43\x61n_rx_grouping_modeType\x12$\n CAN_RX_GROUPING_MODE_NO_GROUPING\x10\x00\x12*\n&CAN_RX_GROUPING_MODE_GROUP_MOVING_ONLY\x10\x01\x12.\n*CAN_RX_GROUPING_MODE_GROUP_STATIONARY_ONLY\x10\x02\x12\x30\n,CAN_RX_GROUPING_MODE_GROUP_MOVING_STATIONARY\x10\x03\"\x92\n\n\x0cVehicle1_4f0\x12g\n\x1e\x63\x61n_rx_steering_angle_validity\x18\x01 \x01(\x0e\x32?.apollo.drivers.Vehicle1_4f0.Can_rx_steering_angle_validityType\x12\"\n\x1a\x63\x61n_rx_steering_angle_rate\x18\x02 \x01(\x05\x12_\n\x1a\x63\x61n_rx_steering_angle_sign\x18\x03 \x01(\x0e\x32;.apollo.drivers.Vehicle1_4f0.Can_rx_steering_angle_signType\x12i\n\x1f\x63\x61n_rx_steering_angle_rate_sign\x18\x04 \x01(\x0e\x32@.apollo.drivers.Vehicle1_4f0.Can_rx_steering_angle_rate_signType\x12\x1d\n\x15\x63\x61n_rx_steering_angle\x18\x05 \x01(\x05\x12\x1f\n\x17\x63\x61n_rx_radius_curvature\x18\x06 \x01(\x05\x12[\n\x18\x63\x61n_rx_yaw_rate_validity\x18\x07 \x01(\x0e\x32\x39.apollo.drivers.Vehicle1_4f0.Can_rx_yaw_rate_validityType\x12\x17\n\x0f\x63\x61n_rx_yaw_rate\x18\x08 \x01(\x01\x12g\n\x1e\x63\x61n_rx_vehicle_speed_direction\x18\t \x01(\x0e\x32?.apollo.drivers.Vehicle1_4f0.Can_rx_vehicle_speed_directionType\x12\x1c\n\x14\x63\x61n_rx_vehicle_speed\x18\n \x01(\x01\"z\n\"Can_rx_steering_angle_validityType\x12*\n&CAN_RX_STEERING_ANGLE_VALIDITY_INVALID\x10\x00\x12(\n$CAN_RX_STEERING_ANGLE_VALIDITY_VALID\x10\x01\"{\n\x1e\x43\x61n_rx_steering_angle_signType\x12/\n+CAN_RX_STEERING_ANGLE_SIGN_COUNTERCLOCKWISE\x10\x00\x12(\n$CAN_RX_STEERING_ANGLE_SIGN_CLOCKWISE\x10\x01\"\x8a\x01\n#Can_rx_steering_angle_rate_signType\x12\x34\n0CAN_RX_STEERING_ANGLE_RATE_SIGN_COUNTERCLOCKWISE\x10\x00\x12-\n)CAN_RX_STEERING_ANGLE_RATE_SIGN_CLOCKWISE\x10\x01\"h\n\x1c\x43\x61n_rx_yaw_rate_validityType\x12$\n CAN_RX_YAW_RATE_VALIDITY_INVALID\x10\x00\x12\"\n\x1e\x43\x41N_RX_YAW_RATE_VALIDITY_VALID\x10\x01\"|\n\"Can_rx_vehicle_speed_directionType\x12*\n&CAN_RX_VEHICLE_SPEED_DIRECTION_FORWARD\x10\x00\x12*\n&CAN_RX_VEHICLE_SPEED_DIRECTION_REVERSE\x10\x01\"\x82\x08\n\x0c\x45sr_sim1_5c0\x12Q\n\x13\x63\x61n_rx_sim_track_id\x18\x01 \x01(\x0e\x32\x34.apollo.drivers.Esr_sim1_5c0.Can_rx_sim_track_idType\x12M\n\x11\x63\x61n_rx_sim_status\x18\x02 \x01(\x0e\x32\x32.apollo.drivers.Esr_sim1_5c0.Can_rx_sim_statusType\x12\x1d\n\x15\x63\x61n_rx_sim_range_rate\x18\x03 \x01(\x01\x12\x1e\n\x16\x63\x61n_rx_sim_range_accel\x18\x04 \x01(\x01\x12\x18\n\x10\x63\x61n_rx_sim_range\x18\x05 \x01(\x05\x12\x1b\n\x13\x63\x61n_rx_sim_lat_rate\x18\x06 \x01(\x01\x12\x1a\n\x12\x63\x61n_rx_sim_lat_pos\x18\x07 \x01(\x01\x12Q\n\x13\x63\x61n_rx_sim_function\x18\x08 \x01(\x0e\x32\x34.apollo.drivers.Esr_sim1_5c0.Can_rx_sim_functionType\x12\x18\n\x10\x63\x61n_rx_sim_angle\x18\t \x01(\x01\"\x80\x01\n\x17\x43\x61n_rx_sim_track_idType\x12!\n\x1d\x43\x41N_RX_SIM_TRACK_ID_NO_TARGET\x10\x00\x12 \n\x1c\x43\x41N_RX_SIM_TRACK_ID_TARGET_1\x10\x01\x12 \n\x1c\x43\x41N_RX_SIM_TRACK_ID_TARGET_2\x10\x02\"\x8f\x01\n\x15\x43\x61n_rx_sim_statusType\x12\x1d\n\x19\x43\x41N_RX_SIM_STATUS_INVALID\x10\x00\x12\x19\n\x15\x43\x41N_RX_SIM_STATUS_NEW\x10\x01\x12\x1d\n\x19\x43\x41N_RX_SIM_STATUS_UPDATED\x10\x02\x12\x1d\n\x19\x43\x41N_RX_SIM_STATUS_COASTED\x10\x03\"\xbb\x02\n\x17\x43\x61n_rx_sim_functionType\x12\x1b\n\x17\x43\x41N_RX_SIM_FUNCTION_ACC\x10\x00\x12\x1a\n\x16\x43\x41N_RX_SIM_FUNCTION_RI\x10\x01\x12 \n\x1c\x43\x41N_RX_SIM_FUNCTION_FCW_MOVE\x10\x02\x12 \n\x1c\x43\x41N_RX_SIM_FUNCTION_FCW_STAT\x10\x03\x12!\n\x1d\x43\x41N_RX_SIM_FUNCTION_CMBB_MOVE\x10\x04\x12!\n\x1d\x43\x41N_RX_SIM_FUNCTION_CMBB_STAT\x10\x05\x12/\n+CAN_RX_SIM_FUNCTION_ALL_MOVING_ACC_FCW_CMBB\x10\x06\x12,\n(CAN_RX_SIM_FUNCTION_ALL_STAT_RI_FCW_CMBB\x10\x07\"\xec\x01\n\x0f\x45sr_status1_4e0\x12\x1c\n\x14\x63\x61n_tx_dsp_timestamp\x18\x01 \x01(\x01\x12\x19\n\x11\x63\x61n_tx_comm_error\x18\x02 \x01(\x08\x12\x1c\n\x14\x63\x61n_tx_yaw_rate_calc\x18\x03 \x01(\x01\x12!\n\x19\x63\x61n_tx_vehicle_speed_calc\x18\x04 \x01(\x01\x12\x19\n\x11\x63\x61n_tx_scan_index\x18\x05 \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_rolling_count_1\x18\x06 \x01(\x05\x12$\n\x1c\x63\x61n_tx_radius_curvature_calc\x18\x07 \x01(\x05\"\xdd\x0b\n\x0f\x45sr_status2_4e1\x12\x1c\n\x14\x63\x61n_tx_yaw_rate_bias\x18\x01 \x01(\x01\x12\"\n\x1a\x63\x61n_tx_veh_spd_comp_factor\x18\x02 \x01(\x01\x12\x1d\n\x15\x63\x61n_tx_sw_version_dsp\x18\x03 \x01(\x05\x12\x1a\n\x12\x63\x61n_tx_temperature\x18\x04 \x01(\x05\x12V\n\x14\x63\x61n_tx_raw_data_mode\x18\x05 \x01(\x0e\x32\x38.apollo.drivers.Esr_status2_4e1.Can_tx_raw_data_modeType\x12\\\n\x17\x63\x61n_tx_range_perf_error\x18\x06 \x01(\x0e\x32;.apollo.drivers.Esr_status2_4e1.Can_tx_range_perf_errorType\x12X\n\x15\x63\x61n_tx_overheat_error\x18\x07 \x01(\x0e\x32\x39.apollo.drivers.Esr_status2_4e1.Can_tx_overheat_errorType\x12!\n\x19\x63\x61n_tx_maximum_tracks_ack\x18\x08 \x01(\x05\x12X\n\x15\x63\x61n_tx_internal_error\x18\t \x01(\x0e\x32\x39.apollo.drivers.Esr_status2_4e1.Can_tx_internal_errorType\x12V\n\x14\x63\x61n_tx_grouping_mode\x18\n \x01(\x0e\x32\x38.apollo.drivers.Esr_status2_4e1.Can_tx_grouping_modeType\x12\\\n\x17\x63\x61n_tx_xcvr_operational\x18\x0b \x01(\x0e\x32;.apollo.drivers.Esr_status2_4e1.Can_tx_xcvr_operationalType\x12!\n\x19\x63\x61n_tx_steering_angle_ack\x18\x0c \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_rolling_count_2\x18\r \x01(\x05\"[\n\x18\x43\x61n_tx_raw_data_modeType\x12!\n\x1d\x43\x41N_TX_RAW_DATA_MODE_FILTERED\x10\x00\x12\x1c\n\x18\x43\x41N_TX_RAW_DATA_MODE_RAW\x10\x01\"k\n\x1b\x43\x61n_tx_range_perf_errorType\x12\'\n#CAN_TX_RANGE_PERF_ERROR_NOT_BLOCKED\x10\x00\x12#\n\x1f\x43\x41N_TX_RANGE_PERF_ERROR_BLOCKED\x10\x01\"g\n\x19\x43\x61n_tx_overheat_errorType\x12&\n\"CAN_TX_OVERHEAT_ERROR_NOT_OVERTEMP\x10\x00\x12\"\n\x1e\x43\x41N_TX_OVERHEAT_ERROR_OVERTEMP\x10\x01\"c\n\x19\x43\x61n_tx_internal_errorType\x12$\n CAN_TX_INTERNAL_ERROR_NOT_FAILED\x10\x00\x12 \n\x1c\x43\x41N_TX_INTERNAL_ERROR_FAILED\x10\x01\"\xce\x01\n\x18\x43\x61n_tx_grouping_modeType\x12$\n CAN_TX_GROUPING_MODE_NO_GROUPING\x10\x00\x12*\n&CAN_TX_GROUPING_MODE_GROUP_MOVING_ONLY\x10\x01\x12.\n*CAN_TX_GROUPING_MODE_GROUP_STATIONARY_ONLY\x10\x02\x12\x30\n,CAN_TX_GROUPING_MODE_GROUP_MOVING_STATIONARY\x10\x03\"^\n\x1b\x43\x61n_tx_xcvr_operationalType\x12\x1f\n\x1b\x43\x41N_TX_XCVR_OPERATIONAL_OFF\x10\x00\x12\x1e\n\x1a\x43\x41N_TX_XCVR_OPERATIONAL_ON\x10\x01\"\x91\x02\n\x0f\x45sr_status8_5e7\x12\x1e\n\x16\x63\x61n_tx_history_fault_7\x18\x01 \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_history_fault_6\x18\x02 \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_history_fault_5\x18\x03 \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_history_fault_4\x18\x04 \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_history_fault_3\x18\x05 \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_history_fault_2\x18\x06 \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_history_fault_1\x18\x07 \x01(\x05\x12\x1e\n\x16\x63\x61n_tx_history_fault_0\x18\x08 \x01(\x05\"\x89\x02\n\x0f\x45sr_status7_5e6\x12\x1d\n\x15\x63\x61n_tx_active_fault_7\x18\x01 \x01(\x05\x12\x1d\n\x15\x63\x61n_tx_active_fault_6\x18\x02 \x01(\x05\x12\x1d\n\x15\x63\x61n_tx_active_fault_5\x18\x03 \x01(\x05\x12\x1d\n\x15\x63\x61n_tx_active_fault_4\x18\x04 \x01(\x05\x12\x1d\n\x15\x63\x61n_tx_active_fault_3\x18\x05 \x01(\x05\x12\x1d\n\x15\x63\x61n_tx_active_fault_2\x18\x06 \x01(\x05\x12\x1d\n\x15\x63\x61n_tx_active_fault_0\x18\x07 \x01(\x05\x12\x1d\n\x15\x63\x61n_tx_active_fault_1\x18\x08 \x01(\x05\"\xf6\r\n\x0cVehicle3_5f2\x12&\n\x1e\x63\x61n_rx_serv_align_updates_need\x18\x01 \x01(\x05\x12W\n\x16\x63\x61n_rx_serv_align_type\x18\x02 \x01(\x0e\x32\x37.apollo.drivers.Vehicle3_5f2.Can_rx_serv_align_typeType\x12[\n\x18\x63\x61n_rx_serv_align_enable\x18\x03 \x01(\x0e\x32\x39.apollo.drivers.Vehicle3_5f2.Can_rx_serv_align_enableType\x12#\n\x1b\x63\x61n_rx_aalign_avg_ctr_total\x18\x04 \x01(\x01\x12\x61\n\x1b\x63\x61n_rx_auto_align_converged\x18\x05 \x01(\x0e\x32<.apollo.drivers.Vehicle3_5f2.Can_rx_auto_align_convergedType\x12]\n\x19\x63\x61n_rx_auto_align_disable\x18\x06 \x01(\x0e\x32:.apollo.drivers.Vehicle3_5f2.Can_rx_auto_align_disableType\x12$\n\x1c\x63\x61n_rx_angle_mounting_offset\x18\x07 \x01(\x01\x12M\n\x11\x63\x61n_rx_wheel_slip\x18\x08 \x01(\x0e\x32\x32.apollo.drivers.Vehicle3_5f2.Can_rx_wheel_slipType\x12\x1b\n\x13\x63\x61n_rx_radar_height\x18\t \x01(\x05\x12\x1b\n\x13\x63\x61n_rx_radar_fov_mr\x18\n \x01(\x05\x12\x1b\n\x13\x63\x61n_rx_radar_fov_lr\x18\x0b \x01(\x05\x12_\n\x1a\x63\x61n_rx_long_accel_validity\x18\x0c \x01(\x0e\x32;.apollo.drivers.Vehicle3_5f2.Can_rx_long_accel_validityType\x12\x19\n\x11\x63\x61n_rx_long_accel\x18\r \x01(\x01\x12]\n\x19\x63\x61n_rx_lat_accel_validity\x18\x0e \x01(\x0e\x32:.apollo.drivers.Vehicle3_5f2.Can_rx_lat_accel_validityType\x12\x18\n\x10\x63\x61n_rx_lat_accel\x18\x0f \x01(\x01\"u\n\x1a\x43\x61n_rx_serv_align_typeType\x12)\n%CAN_RX_SERV_ALIGN_TYPE_AUTO_OR_DEALER\x10\x00\x12,\n(CAN_RX_SERV_ALIGN_TYPE_VOLVO_SHORT_TRACK\x10\x01\"k\n\x1c\x43\x61n_rx_serv_align_enableType\x12%\n!CAN_RX_SERV_ALIGN_ENABLE_DISABLED\x10\x00\x12$\n CAN_RX_SERV_ALIGN_ENABLE_ENABLED\x10\x01\"{\n\x1f\x43\x61n_rx_auto_align_convergedType\x12-\n)CAN_RX_AUTO_ALIGN_CONVERGED_NOT_CONVERGED\x10\x00\x12)\n%CAN_RX_AUTO_ALIGN_CONVERGED_CONVERGED\x10\x01\"n\n\x1d\x43\x61n_rx_auto_align_disableType\x12%\n!CAN_RX_AUTO_ALIGN_DISABLE_ENABLED\x10\x00\x12&\n\"CAN_RX_AUTO_ALIGN_DISABLE_DISABLED\x10\x01\"\xb1\x01\n\x15\x43\x61n_rx_wheel_slipType\x12 \n\x1c\x43\x41N_RX_WHEEL_SLIP_NO_CONTROL\x10\x00\x12(\n$CAN_RX_WHEEL_SLIP_BRAKE_SLIP_CONTROL\x10\x01\x12+\n\'CAN_RX_WHEEL_SLIP_TRACTION_SLIP_CONTROL\x10\x02\x12\x1f\n\x1b\x43\x41N_RX_WHEEL_SLIP_INVALID_3\x10\x03\"n\n\x1e\x43\x61n_rx_long_accel_validityType\x12&\n\"CAN_RX_LONG_ACCEL_VALIDITY_INVALID\x10\x00\x12$\n CAN_RX_LONG_ACCEL_VALIDITY_VALID\x10\x01\"k\n\x1d\x43\x61n_rx_lat_accel_validityType\x12%\n!CAN_RX_LAT_ACCEL_VALIDITY_INVALID\x10\x00\x12#\n\x1f\x43\x41N_RX_LAT_ACCEL_VALIDITY_VALID\x10\x01\"\x91\x05\n\x0cVehicle4_5f3\x12 \n\x18\x63\x61n_rx_fac_tgt_range_r2m\x18\x01 \x01(\x01\x12 \n\x18\x63\x61n_rx_fac_tgt_range_m2t\x18\x02 \x01(\x01\x12\x1e\n\x16\x63\x61n_rx_fac_tgt_range_1\x18\x03 \x01(\x01\x12$\n\x1c\x63\x61n_rx_fac_tgt_mtg_space_ver\x18\x04 \x01(\x05\x12$\n\x1c\x63\x61n_rx_fac_tgt_mtg_space_hor\x18\x05 \x01(\x05\x12!\n\x19\x63\x61n_rx_fac_tgt_mtg_offset\x18\x06 \x01(\x05\x12!\n\x19\x63\x61n_rx_fac_align_samp_req\x18\x07 \x01(\x05\x12\x1f\n\x17\x63\x61n_rx_fac_align_max_nt\x18\x08 \x01(\x05\x12W\n\x16\x63\x61n_rx_fac_align_cmd_2\x18\t \x01(\x0e\x32\x37.apollo.drivers.Vehicle4_5f3.Can_rx_fac_align_cmd_2Type\x12W\n\x16\x63\x61n_rx_fac_align_cmd_1\x18\n \x01(\x0e\x32\x37.apollo.drivers.Vehicle4_5f3.Can_rx_fac_align_cmd_1Type\"[\n\x1a\x43\x61n_rx_fac_align_cmd_2Type\x12\x1e\n\x1a\x43\x41N_RX_FAC_ALIGN_CMD_2_OFF\x10\x00\x12\x1d\n\x19\x43\x41N_RX_FAC_ALIGN_CMD_2_ON\x10\x01\"[\n\x1a\x43\x61n_rx_fac_align_cmd_1Type\x12\x1e\n\x1a\x43\x41N_RX_FAC_ALIGN_CMD_1_OFF\x10\x00\x12\x1d\n\x19\x43\x41N_RX_FAC_ALIGN_CMD_1_ON\x10\x01\"\xf4\x03\n\x0cVehicle5_5f4\x12_\n\x1a\x63\x61n_rx_yaw_rate_bias_shift\x18\x01 \x01(\x0e\x32;.apollo.drivers.Vehicle5_5f4.Can_rx_yaw_rate_bias_shiftType\x12\"\n\x1a\x63\x61n_rx_steering_gear_ratio\x18\x02 \x01(\x01\x12\x18\n\x10\x63\x61n_rx_wheelbase\x18\x03 \x01(\x01\x12!\n\x19\x63\x61n_rx_distance_rear_axle\x18\x04 \x01(\x01\x12$\n\x1c\x63\x61n_rx_cw_blockage_threshold\x18\x05 \x01(\x01\x12\"\n\x1a\x63\x61n_rx_funnel_offset_right\x18\x06 \x01(\x01\x12!\n\x19\x63\x61n_rx_funnel_offset_left\x18\x07 \x01(\x01\x12\x1d\n\x15\x63\x61n_rx_beamwidth_vert\x18\x08 \x01(\x01\x12#\n\x1b\x63\x61n_rx_oversteer_understeer\x18\t \x01(\x05\"q\n\x1e\x43\x61n_rx_yaw_rate_bias_shiftType\x12(\n$CAN_RX_YAW_RATE_BIAS_SHIFT_NO_DETECT\x10\x00\x12%\n!CAN_RX_YAW_RATE_BIAS_SHIFT_DETECT\x10\x01\"\xd4\x01\n\x0cVehicle6_5f5\x12(\n can_rx_inner_funnel_offset_right\x18\x01 \x01(\x01\x12\'\n\x1f\x63\x61n_rx_inner_funnel_offset_left\x18\x02 \x01(\x01\x12$\n\x1c\x63\x61n_volvo_fa_range_max_short\x18\x03 \x01(\x05\x12%\n\x1d\x63\x61n_volvo_fa_min_vspeed_short\x18\x04 \x01(\x01\x12$\n\x1c\x63\x61n_volvo_fa_aalign_estimate\x18\x05 \x01(\x01\"\x98\n\n\tDelphiESR\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x38\n\x0f\x65sr_status9_5e8\x18\x02 \x01(\x0b\x32\x1f.apollo.drivers.Esr_status9_5e8\x12\x38\n\x0f\x65sr_status6_5e5\x18\x03 \x01(\x0b\x32\x1f.apollo.drivers.Esr_status6_5e5\x12\x38\n\x0f\x65sr_status5_5e4\x18\x04 \x01(\x0b\x32\x1f.apollo.drivers.Esr_status5_5e4\x12\x38\n\x0f\x65sr_status3_4e2\x18\x05 \x01(\x0b\x32\x1f.apollo.drivers.Esr_status3_4e2\x12\x38\n\x0f\x65sr_status4_4e3\x18\x06 \x01(\x0b\x32\x1f.apollo.drivers.Esr_status4_4e3\x12J\n\x18\x65sr_trackmotionpower_540\x18\x07 \x03(\x0b\x32(.apollo.drivers.Esr_trackmotionpower_540\x12:\n\x10\x61\x63m_inst_req_7e0\x18\x08 \x01(\x0b\x32 .apollo.drivers.Acm_inst_req_7e0\x12\x38\n\x0f\x65sr_track01_500\x18\t \x03(\x0b\x32\x1f.apollo.drivers.Esr_track01_500\x12\x36\n\x0e\x65sr_valid1_5d0\x18\n \x01(\x0b\x32\x1e.apollo.drivers.Esr_valid1_5d0\x12\x36\n\x0e\x65sr_valid2_5d1\x18\x0b \x01(\x0b\x32\x1e.apollo.drivers.Esr_valid2_5d1\x12<\n\x11\x61\x63m_inst_resp_7e4\x18\x0c \x01(\x0b\x32!.apollo.drivers.Acm_inst_resp_7e4\x12\x32\n\x0cvehicle2_4f1\x18\r \x01(\x0b\x32\x1c.apollo.drivers.Vehicle2_4f1\x12\x32\n\x0cvehicle1_4f0\x18\x0e \x01(\x0b\x32\x1c.apollo.drivers.Vehicle1_4f0\x12\x32\n\x0c\x65sr_sim1_5c0\x18\x0f \x01(\x0b\x32\x1c.apollo.drivers.Esr_sim1_5c0\x12\x38\n\x0f\x65sr_status1_4e0\x18\x10 \x01(\x0b\x32\x1f.apollo.drivers.Esr_status1_4e0\x12\x38\n\x0f\x65sr_status2_4e1\x18\x11 \x01(\x0b\x32\x1f.apollo.drivers.Esr_status2_4e1\x12\x38\n\x0f\x65sr_status8_5e7\x18\x12 \x01(\x0b\x32\x1f.apollo.drivers.Esr_status8_5e7\x12\x38\n\x0f\x65sr_status7_5e6\x18\x13 \x01(\x0b\x32\x1f.apollo.drivers.Esr_status7_5e6\x12\x32\n\x0cvehicle3_5f2\x18\x14 \x01(\x0b\x32\x1c.apollo.drivers.Vehicle3_5f2\x12\x32\n\x0cvehicle4_5f3\x18\x15 \x01(\x0b\x32\x1c.apollo.drivers.Vehicle4_5f3\x12\x32\n\x0cvehicle5_5f4\x18\x16 \x01(\x0b\x32\x1c.apollo.drivers.Vehicle5_5f4\x12\x32\n\x0cvehicle6_5f5\x18\x17 \x01(\x0b\x32\x1c.apollo.drivers.Vehicle6_5f5'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])



_ESR_STATUS6_5E5_CAN_TX_VERTICAL_ALIGN_UPDATEDTYPE = _descriptor.EnumDescriptor(
  name='Can_tx_vertical_align_updatedType',
  full_name='apollo.drivers.Esr_status6_5e5.Can_tx_vertical_align_updatedType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_VERTICAL_ALIGN_UPDATED_NOT_UPDATED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_VERTICAL_ALIGN_UPDATED_UPDATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1218,
  serialized_end=1343,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS6_5E5_CAN_TX_VERTICAL_ALIGN_UPDATEDTYPE)

_ESR_STATUS6_5E5_CAN_TX_FOUND_TARGETTYPE = _descriptor.EnumDescriptor(
  name='Can_tx_found_targetType',
  full_name='apollo.drivers.Esr_status6_5e5.Can_tx_found_targetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FOUND_TARGET_NOT_FOUND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FOUND_TARGET_FOUND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1345,
  serialized_end=1436,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS6_5E5_CAN_TX_FOUND_TARGETTYPE)

_ESR_STATUS6_5E5_CAN_TX_FACTORY_ALIGN_STATUS_2TYPE = _descriptor.EnumDescriptor(
  name='Can_tx_factory_align_status_2Type',
  full_name='apollo.drivers.Esr_status6_5e5.Can_tx_factory_align_status_2Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FACTORY_ALIGN_STATUS_2_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FACTORY_ALIGN_STATUS_2_BUSY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FACTORY_ALIGN_STATUS_2_SUCCESS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FACTORY_ALIGN_STATUS_2_FAIL_NO_TARGET', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FACTORY_ALIGN_STATUS_2_FAIL_DEV_TOO_LARGE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FACTORY_ALIGN_STATUS_2_FAIL_VAR_TOO_LARGE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1439,
  serialized_end=1754,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS6_5E5_CAN_TX_FACTORY_ALIGN_STATUS_2TYPE)

_ESR_STATUS6_5E5_CAN_TX_FACTORY_ALIGN_STATUS_1TYPE = _descriptor.EnumDescriptor(
  name='Can_tx_factory_align_status_1Type',
  full_name='apollo.drivers.Esr_status6_5e5.Can_tx_factory_align_status_1Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FACTORY_ALIGN_STATUS_1_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FACTORY_ALIGN_STATUS_1_BUSY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FACTORY_ALIGN_STATUS_1_SUCCESS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FACTORY_ALIGN_STATUS_1_FAIL_NO_TARGET', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FACTORY_ALIGN_STATUS_1_FAIL_DEV_TOO_LARGE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_FACTORY_ALIGN_STATUS_1_FAIL_VAR_TOO_LARGE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1757,
  serialized_end=2072,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS6_5E5_CAN_TX_FACTORY_ALIGN_STATUS_1TYPE)

_ESR_STATUS6_5E5_CAN_TX_RECOMMEND_UNCONVERGETYPE = _descriptor.EnumDescriptor(
  name='Can_tx_recommend_unconvergeType',
  full_name='apollo.drivers.Esr_status6_5e5.Can_tx_recommend_unconvergeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_RECOMMEND_UNCONVERGE_NOT_RECOMMEND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_RECOMMEND_UNCONVERGE_RECOMMEND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2074,
  serialized_end=2197,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS6_5E5_CAN_TX_RECOMMEND_UNCONVERGETYPE)

_ESR_STATUS6_5E5_CAN_TX_SYSTEM_POWER_MODETYPE = _descriptor.EnumDescriptor(
  name='Can_tx_system_power_modeType',
  full_name='apollo.drivers.Esr_status6_5e5.Can_tx_system_power_modeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_SYSTEM_POWER_MODE_DSP_INIT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_SYSTEM_POWER_MODE_RADIATE_OFF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_SYSTEM_POWER_MODE_RADIATE_ON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_SYSTEM_POWER_MODE_DSP_SHUTDOWN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_SYSTEM_POWER_MODE_DSP_OFF', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_SYSTEM_POWER_MODE_HOST_SHUTDOWN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_SYSTEM_POWER_MODE_TEST', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_SYSTEM_POWER_MODE_7INVALID', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2200,
  serialized_end=2551,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS6_5E5_CAN_TX_SYSTEM_POWER_MODETYPE)

_ESR_STATUS4_4E3_CAN_TX_TRUCK_TARGET_DETTYPE = _descriptor.EnumDescriptor(
  name='Can_tx_truck_target_detType',
  full_name='apollo.drivers.Esr_status4_4e3.Can_tx_truck_target_detType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRUCK_TARGET_DET_NOT_DETECTED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRUCK_TARGET_DET_DETECTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3730,
  serialized_end=3839,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS4_4E3_CAN_TX_TRUCK_TARGET_DETTYPE)

_ESR_STATUS4_4E3_CAN_TX_LR_ONLY_GRATING_LOBE_DETTYPE = _descriptor.EnumDescriptor(
  name='Can_tx_lr_only_grating_lobe_detType',
  full_name='apollo.drivers.Esr_status4_4e3.Can_tx_lr_only_grating_lobe_detType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_LR_ONLY_GRATING_LOBE_DET_NOT_DETECTED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_LR_ONLY_GRATING_LOBE_DET_DETECTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3842,
  serialized_end=3975,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS4_4E3_CAN_TX_LR_ONLY_GRATING_LOBE_DETTYPE)

_ESR_STATUS4_4E3_CAN_TX_SIDELOBE_BLOCKAGETYPE = _descriptor.EnumDescriptor(
  name='Can_tx_sidelobe_blockageType',
  full_name='apollo.drivers.Esr_status4_4e3.Can_tx_sidelobe_blockageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_SIDELOBE_BLOCKAGE_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_SIDELOBE_BLOCKAGE_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3977,
  serialized_end=4074,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS4_4E3_CAN_TX_SIDELOBE_BLOCKAGETYPE)

_ESR_STATUS4_4E3_CAN_TX_PARTIAL_BLOCKAGETYPE = _descriptor.EnumDescriptor(
  name='Can_tx_partial_blockageType',
  full_name='apollo.drivers.Esr_status4_4e3.Can_tx_partial_blockageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_PARTIAL_BLOCKAGE_NOT_BLOCKED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_PARTIAL_BLOCKAGE_BLOCKED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4076,
  serialized_end=4183,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS4_4E3_CAN_TX_PARTIAL_BLOCKAGETYPE)

_ESR_STATUS4_4E3_CAN_TX_MR_LR_MODETYPE = _descriptor.EnumDescriptor(
  name='Can_tx_mr_lr_modeType',
  full_name='apollo.drivers.Esr_status4_4e3.Can_tx_mr_lr_modeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_MR_LR_MODE_RESERVED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_MR_LR_MODE_OUTPUT_ONLY_MEDIUM_RANGE_TRACKS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_MR_LR_MODE_OUTPUT_ONLY_LONG_RANGE_TRACKS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_MR_LR_MODE_OUTPUT_ALL_MEDIUM_RANGE_AND_LONG', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4186,
  serialized_end=4405,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS4_4E3_CAN_TX_MR_LR_MODETYPE)

_ESR_TRACK01_500_CAN_TX_TRACK_GROUPING_CHANGEDTYPE = _descriptor.EnumDescriptor(
  name='Can_tx_track_grouping_changedType',
  full_name='apollo.drivers.Esr_track01_500.Can_tx_track_grouping_changedType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_GROUPING_CHANGED_GROUPINGUNCHANGED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_GROUPING_CHANGED_GROUPINGCHANGED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5602,
  serialized_end=5741,
)
_sym_db.RegisterEnumDescriptor(_ESR_TRACK01_500_CAN_TX_TRACK_GROUPING_CHANGEDTYPE)

_ESR_TRACK01_500_CAN_TX_TRACK_ONCOMINGTYPE = _descriptor.EnumDescriptor(
  name='Can_tx_track_oncomingType',
  full_name='apollo.drivers.Esr_track01_500.Can_tx_track_oncomingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_ONCOMING_NOTONCOMING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_ONCOMING_ONCOMING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5743,
  serialized_end=5845,
)
_sym_db.RegisterEnumDescriptor(_ESR_TRACK01_500_CAN_TX_TRACK_ONCOMINGTYPE)

_ESR_TRACK01_500_CAN_TX_TRACK_BRIDGE_OBJECTTYPE = _descriptor.EnumDescriptor(
  name='Can_tx_track_bridge_objectType',
  full_name='apollo.drivers.Esr_track01_500.Can_tx_track_bridge_objectType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_BRIDGE_OBJECT_NOT_BRIDGE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_BRIDGE_OBJECT_BRIDGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5847,
  serialized_end=5961,
)
_sym_db.RegisterEnumDescriptor(_ESR_TRACK01_500_CAN_TX_TRACK_BRIDGE_OBJECTTYPE)

_ESR_TRACK01_500_CAN_TX_TRACK_STATUSTYPE = _descriptor.EnumDescriptor(
  name='Can_tx_track_statusType',
  full_name='apollo.drivers.Esr_track01_500.Can_tx_track_statusType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_STATUS_NO_TARGET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_STATUS_NEW_TARGET', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_STATUS_NEW_UPDATED_TARGET', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_STATUS_UPDATED_TARGET', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_STATUS_COASTED_TARGET', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_STATUS_MERGED_TARGET', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_STATUS_INVALID_COASTED_TARGET', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_STATUS_NEW_COASTED_TARGET', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5964,
  serialized_end=6315,
)
_sym_db.RegisterEnumDescriptor(_ESR_TRACK01_500_CAN_TX_TRACK_STATUSTYPE)

_ESR_TRACK01_500_CAN_TX_TRACK_MED_RANGE_MODETYPE = _descriptor.EnumDescriptor(
  name='Can_tx_track_med_range_modeType',
  full_name='apollo.drivers.Esr_track01_500.Can_tx_track_med_range_modeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_MED_RANGE_MODE_NO_MR_LR_UPDATE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_MED_RANGE_MODE_MR_UPDATE_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_MED_RANGE_MODE_LR_UPDATE_ONLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_TRACK_MED_RANGE_MODE_BOTH_MR_LR_UPDATE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6318,
  serialized_end=6547,
)
_sym_db.RegisterEnumDescriptor(_ESR_TRACK01_500_CAN_TX_TRACK_MED_RANGE_MODETYPE)

_VEHICLE2_4F1_CAN_RX_MR_ONLY_TRANSMITTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_mr_only_transmitType',
  full_name='apollo.drivers.Vehicle2_4f1.Can_rx_mr_only_transmitType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_MR_ONLY_TRANSMIT_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_MR_ONLY_TRANSMIT_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8389,
  serialized_end=8483,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE2_4F1_CAN_RX_MR_ONLY_TRANSMITTYPE)

_VEHICLE2_4F1_CAN_RX_LR_ONLY_TRANSMITTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_lr_only_transmitType',
  full_name='apollo.drivers.Vehicle2_4f1.Can_rx_lr_only_transmitType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_LR_ONLY_TRANSMIT_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_LR_ONLY_TRANSMIT_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8485,
  serialized_end=8579,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE2_4F1_CAN_RX_LR_ONLY_TRANSMITTYPE)

_VEHICLE2_4F1_CAN_RX_CLEAR_FAULTSTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_clear_faultsType',
  full_name='apollo.drivers.Vehicle2_4f1.Can_rx_clear_faultsType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_CLEAR_FAULTS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_CLEAR_FAULTS_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8581,
  serialized_end=8663,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE2_4F1_CAN_RX_CLEAR_FAULTSTYPE)

_VEHICLE2_4F1_CAN_RX_USE_ANGLE_MISALIGNMENTTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_use_angle_misalignmentType',
  full_name='apollo.drivers.Vehicle2_4f1.Can_rx_use_angle_misalignmentType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_USE_ANGLE_MISALIGNMENT_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_USE_ANGLE_MISALIGNMENT_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8665,
  serialized_end=8777,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE2_4F1_CAN_RX_USE_ANGLE_MISALIGNMENTTYPE)

_VEHICLE2_4F1_CAN_RX_TURN_SIGNAL_STATUSTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_turn_signal_statusType',
  full_name='apollo.drivers.Vehicle2_4f1.Can_rx_turn_signal_statusType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_TURN_SIGNAL_STATUS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_TURN_SIGNAL_STATUS_LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_TURN_SIGNAL_STATUS_RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_TURN_SIGNAL_STATUS_INVALID_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8780,
  serialized_end=8960,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE2_4F1_CAN_RX_TURN_SIGNAL_STATUSTYPE)

_VEHICLE2_4F1_CAN_RX_BLOCKAGE_DISABLETYPE = _descriptor.EnumDescriptor(
  name='Can_rx_blockage_disableType',
  full_name='apollo.drivers.Vehicle2_4f1.Can_rx_blockage_disableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_BLOCKAGE_DISABLE_ENABLED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_BLOCKAGE_DISABLE_DISABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8962,
  serialized_end=9066,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE2_4F1_CAN_RX_BLOCKAGE_DISABLETYPE)

_VEHICLE2_4F1_CAN_RX_VEHICLE_SPEED_VALIDITYTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_vehicle_speed_validityType',
  full_name='apollo.drivers.Vehicle2_4f1.Can_rx_vehicle_speed_validityType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_VEHICLE_SPEED_VALIDITY_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_VEHICLE_SPEED_VALIDITY_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9068,
  serialized_end=9187,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE2_4F1_CAN_RX_VEHICLE_SPEED_VALIDITYTYPE)

_VEHICLE2_4F1_CAN_RX_MMR_UPSIDE_DOWNTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_mmr_upside_downType',
  full_name='apollo.drivers.Vehicle2_4f1.Can_rx_mmr_upside_downType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_MMR_UPSIDE_DOWN_RIGHT_SIDE_UP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_MMR_UPSIDE_DOWN_UPSIDE_DOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9189,
  serialized_end=9299,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE2_4F1_CAN_RX_MMR_UPSIDE_DOWNTYPE)

_VEHICLE2_4F1_CAN_RX_WIPER_STATUSTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_wiper_statusType',
  full_name='apollo.drivers.Vehicle2_4f1.Can_rx_wiper_statusType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_WIPER_STATUS_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_WIPER_STATUS_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9301,
  serialized_end=9383,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE2_4F1_CAN_RX_WIPER_STATUSTYPE)

_VEHICLE2_4F1_CAN_RX_RAW_DATA_ENABLETYPE = _descriptor.EnumDescriptor(
  name='Can_rx_raw_data_enableType',
  full_name='apollo.drivers.Vehicle2_4f1.Can_rx_raw_data_enableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_RAW_DATA_ENABLE_FILTERED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_RAW_DATA_ENABLE_RAW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9385,
  serialized_end=9482,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE2_4F1_CAN_RX_RAW_DATA_ENABLETYPE)

_VEHICLE2_4F1_CAN_RX_RADAR_CMD_RADIATETYPE = _descriptor.EnumDescriptor(
  name='Can_rx_radar_cmd_radiateType',
  full_name='apollo.drivers.Vehicle2_4f1.Can_rx_radar_cmd_radiateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_RADAR_CMD_RADIATE_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_RADAR_CMD_RADIATE_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9484,
  serialized_end=9581,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE2_4F1_CAN_RX_RADAR_CMD_RADIATETYPE)

_VEHICLE2_4F1_CAN_RX_GROUPING_MODETYPE = _descriptor.EnumDescriptor(
  name='Can_rx_grouping_modeType',
  full_name='apollo.drivers.Vehicle2_4f1.Can_rx_grouping_modeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_GROUPING_MODE_NO_GROUPING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_GROUPING_MODE_GROUP_MOVING_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_GROUPING_MODE_GROUP_STATIONARY_ONLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_GROUPING_MODE_GROUP_MOVING_STATIONARY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9584,
  serialized_end=9790,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE2_4F1_CAN_RX_GROUPING_MODETYPE)

_VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_VALIDITYTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_steering_angle_validityType',
  full_name='apollo.drivers.Vehicle1_4f0.Can_rx_steering_angle_validityType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_STEERING_ANGLE_VALIDITY_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_STEERING_ANGLE_VALIDITY_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10471,
  serialized_end=10593,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_VALIDITYTYPE)

_VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_SIGNTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_steering_angle_signType',
  full_name='apollo.drivers.Vehicle1_4f0.Can_rx_steering_angle_signType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_STEERING_ANGLE_SIGN_COUNTERCLOCKWISE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_STEERING_ANGLE_SIGN_CLOCKWISE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10595,
  serialized_end=10718,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_SIGNTYPE)

_VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_RATE_SIGNTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_steering_angle_rate_signType',
  full_name='apollo.drivers.Vehicle1_4f0.Can_rx_steering_angle_rate_signType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_STEERING_ANGLE_RATE_SIGN_COUNTERCLOCKWISE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_STEERING_ANGLE_RATE_SIGN_CLOCKWISE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10721,
  serialized_end=10859,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_RATE_SIGNTYPE)

_VEHICLE1_4F0_CAN_RX_YAW_RATE_VALIDITYTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_yaw_rate_validityType',
  full_name='apollo.drivers.Vehicle1_4f0.Can_rx_yaw_rate_validityType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_YAW_RATE_VALIDITY_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_YAW_RATE_VALIDITY_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10861,
  serialized_end=10965,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE1_4F0_CAN_RX_YAW_RATE_VALIDITYTYPE)

_VEHICLE1_4F0_CAN_RX_VEHICLE_SPEED_DIRECTIONTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_vehicle_speed_directionType',
  full_name='apollo.drivers.Vehicle1_4f0.Can_rx_vehicle_speed_directionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_VEHICLE_SPEED_DIRECTION_FORWARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_VEHICLE_SPEED_DIRECTION_REVERSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10967,
  serialized_end=11091,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE1_4F0_CAN_RX_VEHICLE_SPEED_DIRECTIONTYPE)

_ESR_SIM1_5C0_CAN_RX_SIM_TRACK_IDTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_sim_track_idType',
  full_name='apollo.drivers.Esr_sim1_5c0.Can_rx_sim_track_idType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_TRACK_ID_NO_TARGET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_TRACK_ID_TARGET_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_TRACK_ID_TARGET_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11528,
  serialized_end=11656,
)
_sym_db.RegisterEnumDescriptor(_ESR_SIM1_5C0_CAN_RX_SIM_TRACK_IDTYPE)

_ESR_SIM1_5C0_CAN_RX_SIM_STATUSTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_sim_statusType',
  full_name='apollo.drivers.Esr_sim1_5c0.Can_rx_sim_statusType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_STATUS_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_STATUS_NEW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_STATUS_UPDATED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_STATUS_COASTED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11659,
  serialized_end=11802,
)
_sym_db.RegisterEnumDescriptor(_ESR_SIM1_5C0_CAN_RX_SIM_STATUSTYPE)

_ESR_SIM1_5C0_CAN_RX_SIM_FUNCTIONTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_sim_functionType',
  full_name='apollo.drivers.Esr_sim1_5c0.Can_rx_sim_functionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_FUNCTION_ACC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_FUNCTION_RI', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_FUNCTION_FCW_MOVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_FUNCTION_FCW_STAT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_FUNCTION_CMBB_MOVE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_FUNCTION_CMBB_STAT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_FUNCTION_ALL_MOVING_ACC_FCW_CMBB', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SIM_FUNCTION_ALL_STAT_RI_FCW_CMBB', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11805,
  serialized_end=12120,
)
_sym_db.RegisterEnumDescriptor(_ESR_SIM1_5C0_CAN_RX_SIM_FUNCTIONTYPE)

_ESR_STATUS2_4E1_CAN_TX_RAW_DATA_MODETYPE = _descriptor.EnumDescriptor(
  name='Can_tx_raw_data_modeType',
  full_name='apollo.drivers.Esr_status2_4e1.Can_tx_raw_data_modeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_RAW_DATA_MODE_FILTERED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_RAW_DATA_MODE_RAW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13152,
  serialized_end=13243,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS2_4E1_CAN_TX_RAW_DATA_MODETYPE)

_ESR_STATUS2_4E1_CAN_TX_RANGE_PERF_ERRORTYPE = _descriptor.EnumDescriptor(
  name='Can_tx_range_perf_errorType',
  full_name='apollo.drivers.Esr_status2_4e1.Can_tx_range_perf_errorType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_RANGE_PERF_ERROR_NOT_BLOCKED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_RANGE_PERF_ERROR_BLOCKED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13245,
  serialized_end=13352,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS2_4E1_CAN_TX_RANGE_PERF_ERRORTYPE)

_ESR_STATUS2_4E1_CAN_TX_OVERHEAT_ERRORTYPE = _descriptor.EnumDescriptor(
  name='Can_tx_overheat_errorType',
  full_name='apollo.drivers.Esr_status2_4e1.Can_tx_overheat_errorType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_OVERHEAT_ERROR_NOT_OVERTEMP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_OVERHEAT_ERROR_OVERTEMP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13354,
  serialized_end=13457,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS2_4E1_CAN_TX_OVERHEAT_ERRORTYPE)

_ESR_STATUS2_4E1_CAN_TX_INTERNAL_ERRORTYPE = _descriptor.EnumDescriptor(
  name='Can_tx_internal_errorType',
  full_name='apollo.drivers.Esr_status2_4e1.Can_tx_internal_errorType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_INTERNAL_ERROR_NOT_FAILED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_INTERNAL_ERROR_FAILED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13459,
  serialized_end=13558,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS2_4E1_CAN_TX_INTERNAL_ERRORTYPE)

_ESR_STATUS2_4E1_CAN_TX_GROUPING_MODETYPE = _descriptor.EnumDescriptor(
  name='Can_tx_grouping_modeType',
  full_name='apollo.drivers.Esr_status2_4e1.Can_tx_grouping_modeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_GROUPING_MODE_NO_GROUPING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_GROUPING_MODE_GROUP_MOVING_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_GROUPING_MODE_GROUP_STATIONARY_ONLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_GROUPING_MODE_GROUP_MOVING_STATIONARY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13561,
  serialized_end=13767,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS2_4E1_CAN_TX_GROUPING_MODETYPE)

_ESR_STATUS2_4E1_CAN_TX_XCVR_OPERATIONALTYPE = _descriptor.EnumDescriptor(
  name='Can_tx_xcvr_operationalType',
  full_name='apollo.drivers.Esr_status2_4e1.Can_tx_xcvr_operationalType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_XCVR_OPERATIONAL_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_TX_XCVR_OPERATIONAL_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13769,
  serialized_end=13863,
)
_sym_db.RegisterEnumDescriptor(_ESR_STATUS2_4E1_CAN_TX_XCVR_OPERATIONALTYPE)

_VEHICLE3_5F2_CAN_RX_SERV_ALIGN_TYPETYPE = _descriptor.EnumDescriptor(
  name='Can_rx_serv_align_typeType',
  full_name='apollo.drivers.Vehicle3_5f2.Can_rx_serv_align_typeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SERV_ALIGN_TYPE_AUTO_OR_DEALER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SERV_ALIGN_TYPE_VOLVO_SHORT_TRACK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15328,
  serialized_end=15445,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE3_5F2_CAN_RX_SERV_ALIGN_TYPETYPE)

_VEHICLE3_5F2_CAN_RX_SERV_ALIGN_ENABLETYPE = _descriptor.EnumDescriptor(
  name='Can_rx_serv_align_enableType',
  full_name='apollo.drivers.Vehicle3_5f2.Can_rx_serv_align_enableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SERV_ALIGN_ENABLE_DISABLED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_SERV_ALIGN_ENABLE_ENABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15447,
  serialized_end=15554,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE3_5F2_CAN_RX_SERV_ALIGN_ENABLETYPE)

_VEHICLE3_5F2_CAN_RX_AUTO_ALIGN_CONVERGEDTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_auto_align_convergedType',
  full_name='apollo.drivers.Vehicle3_5f2.Can_rx_auto_align_convergedType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_AUTO_ALIGN_CONVERGED_NOT_CONVERGED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_AUTO_ALIGN_CONVERGED_CONVERGED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15556,
  serialized_end=15679,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE3_5F2_CAN_RX_AUTO_ALIGN_CONVERGEDTYPE)

_VEHICLE3_5F2_CAN_RX_AUTO_ALIGN_DISABLETYPE = _descriptor.EnumDescriptor(
  name='Can_rx_auto_align_disableType',
  full_name='apollo.drivers.Vehicle3_5f2.Can_rx_auto_align_disableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_AUTO_ALIGN_DISABLE_ENABLED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_AUTO_ALIGN_DISABLE_DISABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15681,
  serialized_end=15791,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE3_5F2_CAN_RX_AUTO_ALIGN_DISABLETYPE)

_VEHICLE3_5F2_CAN_RX_WHEEL_SLIPTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_wheel_slipType',
  full_name='apollo.drivers.Vehicle3_5f2.Can_rx_wheel_slipType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_WHEEL_SLIP_NO_CONTROL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_WHEEL_SLIP_BRAKE_SLIP_CONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_WHEEL_SLIP_TRACTION_SLIP_CONTROL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_WHEEL_SLIP_INVALID_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15794,
  serialized_end=15971,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE3_5F2_CAN_RX_WHEEL_SLIPTYPE)

_VEHICLE3_5F2_CAN_RX_LONG_ACCEL_VALIDITYTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_long_accel_validityType',
  full_name='apollo.drivers.Vehicle3_5f2.Can_rx_long_accel_validityType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_LONG_ACCEL_VALIDITY_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_LONG_ACCEL_VALIDITY_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15973,
  serialized_end=16083,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE3_5F2_CAN_RX_LONG_ACCEL_VALIDITYTYPE)

_VEHICLE3_5F2_CAN_RX_LAT_ACCEL_VALIDITYTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_lat_accel_validityType',
  full_name='apollo.drivers.Vehicle3_5f2.Can_rx_lat_accel_validityType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_LAT_ACCEL_VALIDITY_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_LAT_ACCEL_VALIDITY_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16085,
  serialized_end=16192,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE3_5F2_CAN_RX_LAT_ACCEL_VALIDITYTYPE)

_VEHICLE4_5F3_CAN_RX_FAC_ALIGN_CMD_2TYPE = _descriptor.EnumDescriptor(
  name='Can_rx_fac_align_cmd_2Type',
  full_name='apollo.drivers.Vehicle4_5f3.Can_rx_fac_align_cmd_2Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_FAC_ALIGN_CMD_2_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_FAC_ALIGN_CMD_2_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16668,
  serialized_end=16759,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE4_5F3_CAN_RX_FAC_ALIGN_CMD_2TYPE)

_VEHICLE4_5F3_CAN_RX_FAC_ALIGN_CMD_1TYPE = _descriptor.EnumDescriptor(
  name='Can_rx_fac_align_cmd_1Type',
  full_name='apollo.drivers.Vehicle4_5f3.Can_rx_fac_align_cmd_1Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_FAC_ALIGN_CMD_1_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_FAC_ALIGN_CMD_1_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16761,
  serialized_end=16852,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE4_5F3_CAN_RX_FAC_ALIGN_CMD_1TYPE)

_VEHICLE5_5F4_CAN_RX_YAW_RATE_BIAS_SHIFTTYPE = _descriptor.EnumDescriptor(
  name='Can_rx_yaw_rate_bias_shiftType',
  full_name='apollo.drivers.Vehicle5_5f4.Can_rx_yaw_rate_bias_shiftType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_YAW_RATE_BIAS_SHIFT_NO_DETECT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_RX_YAW_RATE_BIAS_SHIFT_DETECT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17242,
  serialized_end=17355,
)
_sym_db.RegisterEnumDescriptor(_VEHICLE5_5F4_CAN_RX_YAW_RATE_BIAS_SHIFTTYPE)


_ESR_STATUS9_5E8 = _descriptor.Descriptor(
  name='Esr_status9_5e8',
  full_name='apollo.drivers.Esr_status9_5e8',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_path_id_acc_3', full_name='apollo.drivers.Esr_status9_5e8.can_tx_path_id_acc_3', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_path_id_acc_2', full_name='apollo.drivers.Esr_status9_5e8.can_tx_path_id_acc_2', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_filtered_xohp_acc_cipv', full_name='apollo.drivers.Esr_status9_5e8.can_tx_filtered_xohp_acc_cipv', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_water_spray_target_id', full_name='apollo.drivers.Esr_status9_5e8.can_tx_water_spray_target_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_serial_num_3rd_byte', full_name='apollo.drivers.Esr_status9_5e8.can_tx_serial_num_3rd_byte', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_sideslip_angle', full_name='apollo.drivers.Esr_status9_5e8.can_tx_sideslip_angle', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_avg_pwr_cwblkg', full_name='apollo.drivers.Esr_status9_5e8.can_tx_avg_pwr_cwblkg', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=346,
)


_ESR_STATUS6_5E5 = _descriptor.Descriptor(
  name='Esr_status6_5e5',
  full_name='apollo.drivers.Esr_status6_5e5',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_sw_version_dsp_3rd_byte', full_name='apollo.drivers.Esr_status6_5e5.can_tx_sw_version_dsp_3rd_byte', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_vertical_align_updated', full_name='apollo.drivers.Esr_status6_5e5.can_tx_vertical_align_updated', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_vertical_misalignment', full_name='apollo.drivers.Esr_status6_5e5.can_tx_vertical_misalignment', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_serv_align_updates_done', full_name='apollo.drivers.Esr_status6_5e5.can_tx_serv_align_updates_done', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_found_target', full_name='apollo.drivers.Esr_status6_5e5.can_tx_found_target', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_factory_misalignment', full_name='apollo.drivers.Esr_status6_5e5.can_tx_factory_misalignment', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_factory_align_status_2', full_name='apollo.drivers.Esr_status6_5e5.can_tx_factory_align_status_2', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_factory_align_status_1', full_name='apollo.drivers.Esr_status6_5e5.can_tx_factory_align_status_1', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_recommend_unconverge', full_name='apollo.drivers.Esr_status6_5e5.can_tx_recommend_unconverge', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_wave_diff_a2d', full_name='apollo.drivers.Esr_status6_5e5.can_tx_wave_diff_a2d', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_system_power_mode', full_name='apollo.drivers.Esr_status6_5e5.can_tx_system_power_mode', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_supply_n5v_a2d', full_name='apollo.drivers.Esr_status6_5e5.can_tx_supply_n5v_a2d', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_supply_1p8v_a2d', full_name='apollo.drivers.Esr_status6_5e5.can_tx_supply_1p8v_a2d', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ESR_STATUS6_5E5_CAN_TX_VERTICAL_ALIGN_UPDATEDTYPE,
    _ESR_STATUS6_5E5_CAN_TX_FOUND_TARGETTYPE,
    _ESR_STATUS6_5E5_CAN_TX_FACTORY_ALIGN_STATUS_2TYPE,
    _ESR_STATUS6_5E5_CAN_TX_FACTORY_ALIGN_STATUS_1TYPE,
    _ESR_STATUS6_5E5_CAN_TX_RECOMMEND_UNCONVERGETYPE,
    _ESR_STATUS6_5E5_CAN_TX_SYSTEM_POWER_MODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=2551,
)


_ESR_STATUS5_5E4 = _descriptor.Descriptor(
  name='Esr_status5_5e4',
  full_name='apollo.drivers.Esr_status5_5e4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_supply_10v_a2d', full_name='apollo.drivers.Esr_status5_5e4.can_tx_supply_10v_a2d', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_temp2_a2d', full_name='apollo.drivers.Esr_status5_5e4.can_tx_temp2_a2d', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_temp1_a2d', full_name='apollo.drivers.Esr_status5_5e4.can_tx_temp1_a2d', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_swbatt_a2d', full_name='apollo.drivers.Esr_status5_5e4.can_tx_swbatt_a2d', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_supply_5vdx_a2d', full_name='apollo.drivers.Esr_status5_5e4.can_tx_supply_5vdx_a2d', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_supply_5va_a2d', full_name='apollo.drivers.Esr_status5_5e4.can_tx_supply_5va_a2d', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_supply_3p3v_a2d', full_name='apollo.drivers.Esr_status5_5e4.can_tx_supply_3p3v_a2d', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_ignp_a2d', full_name='apollo.drivers.Esr_status5_5e4.can_tx_ignp_a2d', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2554,
  serialized_end=2801,
)


_ESR_STATUS3_4E2 = _descriptor.Descriptor(
  name='Esr_status3_4e2',
  full_name='apollo.drivers.Esr_status3_4e2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_sw_version_pld', full_name='apollo.drivers.Esr_status3_4e2.can_tx_sw_version_pld', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_sw_version_host', full_name='apollo.drivers.Esr_status3_4e2.can_tx_sw_version_host', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_hw_version', full_name='apollo.drivers.Esr_status3_4e2.can_tx_hw_version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_interface_version', full_name='apollo.drivers.Esr_status3_4e2.can_tx_interface_version', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_serial_num', full_name='apollo.drivers.Esr_status3_4e2.can_tx_serial_num', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2804,
  serialized_end=2972,
)


_ESR_STATUS4_4E3 = _descriptor.Descriptor(
  name='Esr_status4_4e3',
  full_name='apollo.drivers.Esr_status4_4e3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_truck_target_det', full_name='apollo.drivers.Esr_status4_4e3.can_tx_truck_target_det', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_lr_only_grating_lobe_det', full_name='apollo.drivers.Esr_status4_4e3.can_tx_lr_only_grating_lobe_det', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_sidelobe_blockage', full_name='apollo.drivers.Esr_status4_4e3.can_tx_sidelobe_blockage', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_partial_blockage', full_name='apollo.drivers.Esr_status4_4e3.can_tx_partial_blockage', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_path_id_acc_stat', full_name='apollo.drivers.Esr_status4_4e3.can_tx_path_id_acc_stat', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_mr_lr_mode', full_name='apollo.drivers.Esr_status4_4e3.can_tx_mr_lr_mode', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_auto_align_angle', full_name='apollo.drivers.Esr_status4_4e3.can_tx_auto_align_angle', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_rolling_count_3', full_name='apollo.drivers.Esr_status4_4e3.can_tx_rolling_count_3', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_path_id_fcw_stat', full_name='apollo.drivers.Esr_status4_4e3.can_tx_path_id_fcw_stat', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_path_id_fcw_move', full_name='apollo.drivers.Esr_status4_4e3.can_tx_path_id_fcw_move', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_path_id_cmbb_stat', full_name='apollo.drivers.Esr_status4_4e3.can_tx_path_id_cmbb_stat', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_path_id_cmbb_move', full_name='apollo.drivers.Esr_status4_4e3.can_tx_path_id_cmbb_move', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_path_id_acc', full_name='apollo.drivers.Esr_status4_4e3.can_tx_path_id_acc', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ESR_STATUS4_4E3_CAN_TX_TRUCK_TARGET_DETTYPE,
    _ESR_STATUS4_4E3_CAN_TX_LR_ONLY_GRATING_LOBE_DETTYPE,
    _ESR_STATUS4_4E3_CAN_TX_SIDELOBE_BLOCKAGETYPE,
    _ESR_STATUS4_4E3_CAN_TX_PARTIAL_BLOCKAGETYPE,
    _ESR_STATUS4_4E3_CAN_TX_MR_LR_MODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2975,
  serialized_end=4405,
)


_ESR_TRACKMOTIONPOWER_540_MOTIONPOWER = _descriptor.Descriptor(
  name='Motionpower',
  full_name='apollo.drivers.Esr_trackmotionpower_540.Motionpower',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_track_moving', full_name='apollo.drivers.Esr_trackmotionpower_540.Motionpower.can_tx_track_moving', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_moving_fast', full_name='apollo.drivers.Esr_trackmotionpower_540.Motionpower.can_tx_track_moving_fast', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_moving_slow', full_name='apollo.drivers.Esr_trackmotionpower_540.Motionpower.can_tx_track_moving_slow', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_power', full_name='apollo.drivers.Esr_trackmotionpower_540.Motionpower.can_tx_track_power', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4599,
  serialized_end=4737,
)

_ESR_TRACKMOTIONPOWER_540 = _descriptor.Descriptor(
  name='Esr_trackmotionpower_540',
  full_name='apollo.drivers.Esr_trackmotionpower_540',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_track_rolling_count_2', full_name='apollo.drivers.Esr_trackmotionpower_540.can_tx_track_rolling_count_2', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_can_id_group', full_name='apollo.drivers.Esr_trackmotionpower_540.can_tx_track_can_id_group', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_motion_power', full_name='apollo.drivers.Esr_trackmotionpower_540.can_tx_track_motion_power', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ESR_TRACKMOTIONPOWER_540_MOTIONPOWER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4408,
  serialized_end=4737,
)


_ACM_INST_REQ_7E0 = _descriptor.Descriptor(
  name='Acm_inst_req_7e0',
  full_name='apollo.drivers.Acm_inst_req_7e0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command_ctr', full_name='apollo.drivers.Acm_inst_req_7e0.command_ctr', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_code', full_name='apollo.drivers.Acm_inst_req_7e0.command_code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cc_word_2', full_name='apollo.drivers.Acm_inst_req_7e0.cc_word_2', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cc_word_1', full_name='apollo.drivers.Acm_inst_req_7e0.cc_word_1', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cc_byte_2', full_name='apollo.drivers.Acm_inst_req_7e0.cc_byte_2', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cc_byte_1', full_name='apollo.drivers.Acm_inst_req_7e0.cc_byte_1', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4740,
  serialized_end=4877,
)


_ESR_TRACK01_500 = _descriptor.Descriptor(
  name='Esr_track01_500',
  full_name='apollo.drivers.Esr_track01_500',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_track_grouping_changed', full_name='apollo.drivers.Esr_track01_500.can_tx_track_grouping_changed', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_oncoming', full_name='apollo.drivers.Esr_track01_500.can_tx_track_oncoming', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_lat_rate', full_name='apollo.drivers.Esr_track01_500.can_tx_track_lat_rate', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_bridge_object', full_name='apollo.drivers.Esr_track01_500.can_tx_track_bridge_object', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_width', full_name='apollo.drivers.Esr_track01_500.can_tx_track_width', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_status', full_name='apollo.drivers.Esr_track01_500.can_tx_track_status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_rolling_count', full_name='apollo.drivers.Esr_track01_500.can_tx_track_rolling_count', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_range_rate', full_name='apollo.drivers.Esr_track01_500.can_tx_track_range_rate', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_range_accel', full_name='apollo.drivers.Esr_track01_500.can_tx_track_range_accel', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_range', full_name='apollo.drivers.Esr_track01_500.can_tx_track_range', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_med_range_mode', full_name='apollo.drivers.Esr_track01_500.can_tx_track_med_range_mode', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_track_angle', full_name='apollo.drivers.Esr_track01_500.can_tx_track_angle', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ESR_TRACK01_500_CAN_TX_TRACK_GROUPING_CHANGEDTYPE,
    _ESR_TRACK01_500_CAN_TX_TRACK_ONCOMINGTYPE,
    _ESR_TRACK01_500_CAN_TX_TRACK_BRIDGE_OBJECTTYPE,
    _ESR_TRACK01_500_CAN_TX_TRACK_STATUSTYPE,
    _ESR_TRACK01_500_CAN_TX_TRACK_MED_RANGE_MODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4880,
  serialized_end=6547,
)


_ESR_VALID1_5D0 = _descriptor.Descriptor(
  name='Esr_valid1_5d0',
  full_name='apollo.drivers.Esr_valid1_5d0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_valid_lr_sn', full_name='apollo.drivers.Esr_valid1_5d0.can_tx_valid_lr_sn', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_valid_lr_range_rate', full_name='apollo.drivers.Esr_valid1_5d0.can_tx_valid_lr_range_rate', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_valid_lr_range', full_name='apollo.drivers.Esr_valid1_5d0.can_tx_valid_lr_range', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_valid_lr_power', full_name='apollo.drivers.Esr_valid1_5d0.can_tx_valid_lr_power', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_valid_lr_angle', full_name='apollo.drivers.Esr_valid1_5d0.can_tx_valid_lr_angle', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6550,
  serialized_end=6723,
)


_ESR_VALID2_5D1 = _descriptor.Descriptor(
  name='Esr_valid2_5d1',
  full_name='apollo.drivers.Esr_valid2_5d1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_valid_mr_sn', full_name='apollo.drivers.Esr_valid2_5d1.can_tx_valid_mr_sn', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_valid_mr_range_rate', full_name='apollo.drivers.Esr_valid2_5d1.can_tx_valid_mr_range_rate', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_valid_mr_range', full_name='apollo.drivers.Esr_valid2_5d1.can_tx_valid_mr_range', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_valid_mr_power', full_name='apollo.drivers.Esr_valid2_5d1.can_tx_valid_mr_power', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_valid_mr_angle', full_name='apollo.drivers.Esr_valid2_5d1.can_tx_valid_mr_angle', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6726,
  serialized_end=6899,
)


_ACM_INST_RESP_7E4 = _descriptor.Descriptor(
  name='Acm_inst_resp_7e4',
  full_name='apollo.drivers.Acm_inst_resp_7e4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_7', full_name='apollo.drivers.Acm_inst_resp_7e4.data_7', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_6', full_name='apollo.drivers.Acm_inst_resp_7e4.data_6', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_5', full_name='apollo.drivers.Acm_inst_resp_7e4.data_5', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_4', full_name='apollo.drivers.Acm_inst_resp_7e4.data_4', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_3', full_name='apollo.drivers.Acm_inst_resp_7e4.data_3', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtn_cmd_counter', full_name='apollo.drivers.Acm_inst_resp_7e4.rtn_cmd_counter', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_return_code', full_name='apollo.drivers.Acm_inst_resp_7e4.command_return_code', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pid', full_name='apollo.drivers.Acm_inst_resp_7e4.pid', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6902,
  serialized_end=7068,
)


_VEHICLE2_4F1 = _descriptor.Descriptor(
  name='Vehicle2_4f1',
  full_name='apollo.drivers.Vehicle2_4f1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_rx_volvo_short_track_roc', full_name='apollo.drivers.Vehicle2_4f1.can_rx_volvo_short_track_roc', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_mr_only_transmit', full_name='apollo.drivers.Vehicle2_4f1.can_rx_mr_only_transmit', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_lr_only_transmit', full_name='apollo.drivers.Vehicle2_4f1.can_rx_lr_only_transmit', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_high_yaw_angle', full_name='apollo.drivers.Vehicle2_4f1.can_rx_high_yaw_angle', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_clear_faults', full_name='apollo.drivers.Vehicle2_4f1.can_rx_clear_faults', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_use_angle_misalignment', full_name='apollo.drivers.Vehicle2_4f1.can_rx_use_angle_misalignment', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_turn_signal_status', full_name='apollo.drivers.Vehicle2_4f1.can_rx_turn_signal_status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_blockage_disable', full_name='apollo.drivers.Vehicle2_4f1.can_rx_blockage_disable', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_vehicle_speed_validity', full_name='apollo.drivers.Vehicle2_4f1.can_rx_vehicle_speed_validity', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_mmr_upside_down', full_name='apollo.drivers.Vehicle2_4f1.can_rx_mmr_upside_down', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_wiper_status', full_name='apollo.drivers.Vehicle2_4f1.can_rx_wiper_status', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_raw_data_enable', full_name='apollo.drivers.Vehicle2_4f1.can_rx_raw_data_enable', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_radar_cmd_radiate', full_name='apollo.drivers.Vehicle2_4f1.can_rx_radar_cmd_radiate', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_grouping_mode', full_name='apollo.drivers.Vehicle2_4f1.can_rx_grouping_mode', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_maximum_tracks', full_name='apollo.drivers.Vehicle2_4f1.can_rx_maximum_tracks', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_lateral_mounting_offset', full_name='apollo.drivers.Vehicle2_4f1.can_rx_lateral_mounting_offset', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_angle_misalignment', full_name='apollo.drivers.Vehicle2_4f1.can_rx_angle_misalignment', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_scan_index_ack', full_name='apollo.drivers.Vehicle2_4f1.can_rx_scan_index_ack', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLE2_4F1_CAN_RX_MR_ONLY_TRANSMITTYPE,
    _VEHICLE2_4F1_CAN_RX_LR_ONLY_TRANSMITTYPE,
    _VEHICLE2_4F1_CAN_RX_CLEAR_FAULTSTYPE,
    _VEHICLE2_4F1_CAN_RX_USE_ANGLE_MISALIGNMENTTYPE,
    _VEHICLE2_4F1_CAN_RX_TURN_SIGNAL_STATUSTYPE,
    _VEHICLE2_4F1_CAN_RX_BLOCKAGE_DISABLETYPE,
    _VEHICLE2_4F1_CAN_RX_VEHICLE_SPEED_VALIDITYTYPE,
    _VEHICLE2_4F1_CAN_RX_MMR_UPSIDE_DOWNTYPE,
    _VEHICLE2_4F1_CAN_RX_WIPER_STATUSTYPE,
    _VEHICLE2_4F1_CAN_RX_RAW_DATA_ENABLETYPE,
    _VEHICLE2_4F1_CAN_RX_RADAR_CMD_RADIATETYPE,
    _VEHICLE2_4F1_CAN_RX_GROUPING_MODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7071,
  serialized_end=9790,
)


_VEHICLE1_4F0 = _descriptor.Descriptor(
  name='Vehicle1_4f0',
  full_name='apollo.drivers.Vehicle1_4f0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_rx_steering_angle_validity', full_name='apollo.drivers.Vehicle1_4f0.can_rx_steering_angle_validity', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_steering_angle_rate', full_name='apollo.drivers.Vehicle1_4f0.can_rx_steering_angle_rate', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_steering_angle_sign', full_name='apollo.drivers.Vehicle1_4f0.can_rx_steering_angle_sign', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_steering_angle_rate_sign', full_name='apollo.drivers.Vehicle1_4f0.can_rx_steering_angle_rate_sign', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_steering_angle', full_name='apollo.drivers.Vehicle1_4f0.can_rx_steering_angle', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_radius_curvature', full_name='apollo.drivers.Vehicle1_4f0.can_rx_radius_curvature', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_yaw_rate_validity', full_name='apollo.drivers.Vehicle1_4f0.can_rx_yaw_rate_validity', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_yaw_rate', full_name='apollo.drivers.Vehicle1_4f0.can_rx_yaw_rate', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_vehicle_speed_direction', full_name='apollo.drivers.Vehicle1_4f0.can_rx_vehicle_speed_direction', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_vehicle_speed', full_name='apollo.drivers.Vehicle1_4f0.can_rx_vehicle_speed', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_VALIDITYTYPE,
    _VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_SIGNTYPE,
    _VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_RATE_SIGNTYPE,
    _VEHICLE1_4F0_CAN_RX_YAW_RATE_VALIDITYTYPE,
    _VEHICLE1_4F0_CAN_RX_VEHICLE_SPEED_DIRECTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9793,
  serialized_end=11091,
)


_ESR_SIM1_5C0 = _descriptor.Descriptor(
  name='Esr_sim1_5c0',
  full_name='apollo.drivers.Esr_sim1_5c0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_rx_sim_track_id', full_name='apollo.drivers.Esr_sim1_5c0.can_rx_sim_track_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_sim_status', full_name='apollo.drivers.Esr_sim1_5c0.can_rx_sim_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_sim_range_rate', full_name='apollo.drivers.Esr_sim1_5c0.can_rx_sim_range_rate', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_sim_range_accel', full_name='apollo.drivers.Esr_sim1_5c0.can_rx_sim_range_accel', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_sim_range', full_name='apollo.drivers.Esr_sim1_5c0.can_rx_sim_range', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_sim_lat_rate', full_name='apollo.drivers.Esr_sim1_5c0.can_rx_sim_lat_rate', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_sim_lat_pos', full_name='apollo.drivers.Esr_sim1_5c0.can_rx_sim_lat_pos', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_sim_function', full_name='apollo.drivers.Esr_sim1_5c0.can_rx_sim_function', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_sim_angle', full_name='apollo.drivers.Esr_sim1_5c0.can_rx_sim_angle', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ESR_SIM1_5C0_CAN_RX_SIM_TRACK_IDTYPE,
    _ESR_SIM1_5C0_CAN_RX_SIM_STATUSTYPE,
    _ESR_SIM1_5C0_CAN_RX_SIM_FUNCTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11094,
  serialized_end=12120,
)


_ESR_STATUS1_4E0 = _descriptor.Descriptor(
  name='Esr_status1_4e0',
  full_name='apollo.drivers.Esr_status1_4e0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_dsp_timestamp', full_name='apollo.drivers.Esr_status1_4e0.can_tx_dsp_timestamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_comm_error', full_name='apollo.drivers.Esr_status1_4e0.can_tx_comm_error', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_yaw_rate_calc', full_name='apollo.drivers.Esr_status1_4e0.can_tx_yaw_rate_calc', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_vehicle_speed_calc', full_name='apollo.drivers.Esr_status1_4e0.can_tx_vehicle_speed_calc', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_scan_index', full_name='apollo.drivers.Esr_status1_4e0.can_tx_scan_index', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_rolling_count_1', full_name='apollo.drivers.Esr_status1_4e0.can_tx_rolling_count_1', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_radius_curvature_calc', full_name='apollo.drivers.Esr_status1_4e0.can_tx_radius_curvature_calc', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12123,
  serialized_end=12359,
)


_ESR_STATUS2_4E1 = _descriptor.Descriptor(
  name='Esr_status2_4e1',
  full_name='apollo.drivers.Esr_status2_4e1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_yaw_rate_bias', full_name='apollo.drivers.Esr_status2_4e1.can_tx_yaw_rate_bias', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_veh_spd_comp_factor', full_name='apollo.drivers.Esr_status2_4e1.can_tx_veh_spd_comp_factor', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_sw_version_dsp', full_name='apollo.drivers.Esr_status2_4e1.can_tx_sw_version_dsp', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_temperature', full_name='apollo.drivers.Esr_status2_4e1.can_tx_temperature', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_raw_data_mode', full_name='apollo.drivers.Esr_status2_4e1.can_tx_raw_data_mode', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_range_perf_error', full_name='apollo.drivers.Esr_status2_4e1.can_tx_range_perf_error', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_overheat_error', full_name='apollo.drivers.Esr_status2_4e1.can_tx_overheat_error', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_maximum_tracks_ack', full_name='apollo.drivers.Esr_status2_4e1.can_tx_maximum_tracks_ack', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_internal_error', full_name='apollo.drivers.Esr_status2_4e1.can_tx_internal_error', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_grouping_mode', full_name='apollo.drivers.Esr_status2_4e1.can_tx_grouping_mode', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_xcvr_operational', full_name='apollo.drivers.Esr_status2_4e1.can_tx_xcvr_operational', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_steering_angle_ack', full_name='apollo.drivers.Esr_status2_4e1.can_tx_steering_angle_ack', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_rolling_count_2', full_name='apollo.drivers.Esr_status2_4e1.can_tx_rolling_count_2', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ESR_STATUS2_4E1_CAN_TX_RAW_DATA_MODETYPE,
    _ESR_STATUS2_4E1_CAN_TX_RANGE_PERF_ERRORTYPE,
    _ESR_STATUS2_4E1_CAN_TX_OVERHEAT_ERRORTYPE,
    _ESR_STATUS2_4E1_CAN_TX_INTERNAL_ERRORTYPE,
    _ESR_STATUS2_4E1_CAN_TX_GROUPING_MODETYPE,
    _ESR_STATUS2_4E1_CAN_TX_XCVR_OPERATIONALTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12362,
  serialized_end=13863,
)


_ESR_STATUS8_5E7 = _descriptor.Descriptor(
  name='Esr_status8_5e7',
  full_name='apollo.drivers.Esr_status8_5e7',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_history_fault_7', full_name='apollo.drivers.Esr_status8_5e7.can_tx_history_fault_7', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_history_fault_6', full_name='apollo.drivers.Esr_status8_5e7.can_tx_history_fault_6', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_history_fault_5', full_name='apollo.drivers.Esr_status8_5e7.can_tx_history_fault_5', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_history_fault_4', full_name='apollo.drivers.Esr_status8_5e7.can_tx_history_fault_4', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_history_fault_3', full_name='apollo.drivers.Esr_status8_5e7.can_tx_history_fault_3', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_history_fault_2', full_name='apollo.drivers.Esr_status8_5e7.can_tx_history_fault_2', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_history_fault_1', full_name='apollo.drivers.Esr_status8_5e7.can_tx_history_fault_1', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_history_fault_0', full_name='apollo.drivers.Esr_status8_5e7.can_tx_history_fault_0', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13866,
  serialized_end=14139,
)


_ESR_STATUS7_5E6 = _descriptor.Descriptor(
  name='Esr_status7_5e6',
  full_name='apollo.drivers.Esr_status7_5e6',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_tx_active_fault_7', full_name='apollo.drivers.Esr_status7_5e6.can_tx_active_fault_7', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_active_fault_6', full_name='apollo.drivers.Esr_status7_5e6.can_tx_active_fault_6', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_active_fault_5', full_name='apollo.drivers.Esr_status7_5e6.can_tx_active_fault_5', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_active_fault_4', full_name='apollo.drivers.Esr_status7_5e6.can_tx_active_fault_4', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_active_fault_3', full_name='apollo.drivers.Esr_status7_5e6.can_tx_active_fault_3', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_active_fault_2', full_name='apollo.drivers.Esr_status7_5e6.can_tx_active_fault_2', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_active_fault_0', full_name='apollo.drivers.Esr_status7_5e6.can_tx_active_fault_0', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_tx_active_fault_1', full_name='apollo.drivers.Esr_status7_5e6.can_tx_active_fault_1', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14142,
  serialized_end=14407,
)


_VEHICLE3_5F2 = _descriptor.Descriptor(
  name='Vehicle3_5f2',
  full_name='apollo.drivers.Vehicle3_5f2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_rx_serv_align_updates_need', full_name='apollo.drivers.Vehicle3_5f2.can_rx_serv_align_updates_need', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_serv_align_type', full_name='apollo.drivers.Vehicle3_5f2.can_rx_serv_align_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_serv_align_enable', full_name='apollo.drivers.Vehicle3_5f2.can_rx_serv_align_enable', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_aalign_avg_ctr_total', full_name='apollo.drivers.Vehicle3_5f2.can_rx_aalign_avg_ctr_total', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_auto_align_converged', full_name='apollo.drivers.Vehicle3_5f2.can_rx_auto_align_converged', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_auto_align_disable', full_name='apollo.drivers.Vehicle3_5f2.can_rx_auto_align_disable', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_angle_mounting_offset', full_name='apollo.drivers.Vehicle3_5f2.can_rx_angle_mounting_offset', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_wheel_slip', full_name='apollo.drivers.Vehicle3_5f2.can_rx_wheel_slip', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_radar_height', full_name='apollo.drivers.Vehicle3_5f2.can_rx_radar_height', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_radar_fov_mr', full_name='apollo.drivers.Vehicle3_5f2.can_rx_radar_fov_mr', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_radar_fov_lr', full_name='apollo.drivers.Vehicle3_5f2.can_rx_radar_fov_lr', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_long_accel_validity', full_name='apollo.drivers.Vehicle3_5f2.can_rx_long_accel_validity', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_long_accel', full_name='apollo.drivers.Vehicle3_5f2.can_rx_long_accel', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_lat_accel_validity', full_name='apollo.drivers.Vehicle3_5f2.can_rx_lat_accel_validity', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_lat_accel', full_name='apollo.drivers.Vehicle3_5f2.can_rx_lat_accel', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLE3_5F2_CAN_RX_SERV_ALIGN_TYPETYPE,
    _VEHICLE3_5F2_CAN_RX_SERV_ALIGN_ENABLETYPE,
    _VEHICLE3_5F2_CAN_RX_AUTO_ALIGN_CONVERGEDTYPE,
    _VEHICLE3_5F2_CAN_RX_AUTO_ALIGN_DISABLETYPE,
    _VEHICLE3_5F2_CAN_RX_WHEEL_SLIPTYPE,
    _VEHICLE3_5F2_CAN_RX_LONG_ACCEL_VALIDITYTYPE,
    _VEHICLE3_5F2_CAN_RX_LAT_ACCEL_VALIDITYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14410,
  serialized_end=16192,
)


_VEHICLE4_5F3 = _descriptor.Descriptor(
  name='Vehicle4_5f3',
  full_name='apollo.drivers.Vehicle4_5f3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_rx_fac_tgt_range_r2m', full_name='apollo.drivers.Vehicle4_5f3.can_rx_fac_tgt_range_r2m', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_fac_tgt_range_m2t', full_name='apollo.drivers.Vehicle4_5f3.can_rx_fac_tgt_range_m2t', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_fac_tgt_range_1', full_name='apollo.drivers.Vehicle4_5f3.can_rx_fac_tgt_range_1', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_fac_tgt_mtg_space_ver', full_name='apollo.drivers.Vehicle4_5f3.can_rx_fac_tgt_mtg_space_ver', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_fac_tgt_mtg_space_hor', full_name='apollo.drivers.Vehicle4_5f3.can_rx_fac_tgt_mtg_space_hor', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_fac_tgt_mtg_offset', full_name='apollo.drivers.Vehicle4_5f3.can_rx_fac_tgt_mtg_offset', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_fac_align_samp_req', full_name='apollo.drivers.Vehicle4_5f3.can_rx_fac_align_samp_req', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_fac_align_max_nt', full_name='apollo.drivers.Vehicle4_5f3.can_rx_fac_align_max_nt', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_fac_align_cmd_2', full_name='apollo.drivers.Vehicle4_5f3.can_rx_fac_align_cmd_2', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_fac_align_cmd_1', full_name='apollo.drivers.Vehicle4_5f3.can_rx_fac_align_cmd_1', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLE4_5F3_CAN_RX_FAC_ALIGN_CMD_2TYPE,
    _VEHICLE4_5F3_CAN_RX_FAC_ALIGN_CMD_1TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16195,
  serialized_end=16852,
)


_VEHICLE5_5F4 = _descriptor.Descriptor(
  name='Vehicle5_5f4',
  full_name='apollo.drivers.Vehicle5_5f4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_rx_yaw_rate_bias_shift', full_name='apollo.drivers.Vehicle5_5f4.can_rx_yaw_rate_bias_shift', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_steering_gear_ratio', full_name='apollo.drivers.Vehicle5_5f4.can_rx_steering_gear_ratio', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_wheelbase', full_name='apollo.drivers.Vehicle5_5f4.can_rx_wheelbase', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_distance_rear_axle', full_name='apollo.drivers.Vehicle5_5f4.can_rx_distance_rear_axle', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_cw_blockage_threshold', full_name='apollo.drivers.Vehicle5_5f4.can_rx_cw_blockage_threshold', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_funnel_offset_right', full_name='apollo.drivers.Vehicle5_5f4.can_rx_funnel_offset_right', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_funnel_offset_left', full_name='apollo.drivers.Vehicle5_5f4.can_rx_funnel_offset_left', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_beamwidth_vert', full_name='apollo.drivers.Vehicle5_5f4.can_rx_beamwidth_vert', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_oversteer_understeer', full_name='apollo.drivers.Vehicle5_5f4.can_rx_oversteer_understeer', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLE5_5F4_CAN_RX_YAW_RATE_BIAS_SHIFTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16855,
  serialized_end=17355,
)


_VEHICLE6_5F5 = _descriptor.Descriptor(
  name='Vehicle6_5f5',
  full_name='apollo.drivers.Vehicle6_5f5',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_rx_inner_funnel_offset_right', full_name='apollo.drivers.Vehicle6_5f5.can_rx_inner_funnel_offset_right', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_rx_inner_funnel_offset_left', full_name='apollo.drivers.Vehicle6_5f5.can_rx_inner_funnel_offset_left', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_volvo_fa_range_max_short', full_name='apollo.drivers.Vehicle6_5f5.can_volvo_fa_range_max_short', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_volvo_fa_min_vspeed_short', full_name='apollo.drivers.Vehicle6_5f5.can_volvo_fa_min_vspeed_short', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_volvo_fa_aalign_estimate', full_name='apollo.drivers.Vehicle6_5f5.can_volvo_fa_aalign_estimate', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17358,
  serialized_end=17570,
)


_DELPHIESR = _descriptor.Descriptor(
  name='DelphiESR',
  full_name='apollo.drivers.DelphiESR',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.DelphiESR.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_status9_5e8', full_name='apollo.drivers.DelphiESR.esr_status9_5e8', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_status6_5e5', full_name='apollo.drivers.DelphiESR.esr_status6_5e5', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_status5_5e4', full_name='apollo.drivers.DelphiESR.esr_status5_5e4', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_status3_4e2', full_name='apollo.drivers.DelphiESR.esr_status3_4e2', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_status4_4e3', full_name='apollo.drivers.DelphiESR.esr_status4_4e3', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_trackmotionpower_540', full_name='apollo.drivers.DelphiESR.esr_trackmotionpower_540', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acm_inst_req_7e0', full_name='apollo.drivers.DelphiESR.acm_inst_req_7e0', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_track01_500', full_name='apollo.drivers.DelphiESR.esr_track01_500', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_valid1_5d0', full_name='apollo.drivers.DelphiESR.esr_valid1_5d0', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_valid2_5d1', full_name='apollo.drivers.DelphiESR.esr_valid2_5d1', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acm_inst_resp_7e4', full_name='apollo.drivers.DelphiESR.acm_inst_resp_7e4', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle2_4f1', full_name='apollo.drivers.DelphiESR.vehicle2_4f1', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle1_4f0', full_name='apollo.drivers.DelphiESR.vehicle1_4f0', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_sim1_5c0', full_name='apollo.drivers.DelphiESR.esr_sim1_5c0', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_status1_4e0', full_name='apollo.drivers.DelphiESR.esr_status1_4e0', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_status2_4e1', full_name='apollo.drivers.DelphiESR.esr_status2_4e1', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_status8_5e7', full_name='apollo.drivers.DelphiESR.esr_status8_5e7', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esr_status7_5e6', full_name='apollo.drivers.DelphiESR.esr_status7_5e6', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle3_5f2', full_name='apollo.drivers.DelphiESR.vehicle3_5f2', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle4_5f3', full_name='apollo.drivers.DelphiESR.vehicle4_5f3', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle5_5f4', full_name='apollo.drivers.DelphiESR.vehicle5_5f4', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle6_5f5', full_name='apollo.drivers.DelphiESR.vehicle6_5f5', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17573,
  serialized_end=18877,
)

_ESR_STATUS6_5E5.fields_by_name['can_tx_vertical_align_updated'].enum_type = _ESR_STATUS6_5E5_CAN_TX_VERTICAL_ALIGN_UPDATEDTYPE
_ESR_STATUS6_5E5.fields_by_name['can_tx_found_target'].enum_type = _ESR_STATUS6_5E5_CAN_TX_FOUND_TARGETTYPE
_ESR_STATUS6_5E5.fields_by_name['can_tx_factory_align_status_2'].enum_type = _ESR_STATUS6_5E5_CAN_TX_FACTORY_ALIGN_STATUS_2TYPE
_ESR_STATUS6_5E5.fields_by_name['can_tx_factory_align_status_1'].enum_type = _ESR_STATUS6_5E5_CAN_TX_FACTORY_ALIGN_STATUS_1TYPE
_ESR_STATUS6_5E5.fields_by_name['can_tx_recommend_unconverge'].enum_type = _ESR_STATUS6_5E5_CAN_TX_RECOMMEND_UNCONVERGETYPE
_ESR_STATUS6_5E5.fields_by_name['can_tx_system_power_mode'].enum_type = _ESR_STATUS6_5E5_CAN_TX_SYSTEM_POWER_MODETYPE
_ESR_STATUS6_5E5_CAN_TX_VERTICAL_ALIGN_UPDATEDTYPE.containing_type = _ESR_STATUS6_5E5
_ESR_STATUS6_5E5_CAN_TX_FOUND_TARGETTYPE.containing_type = _ESR_STATUS6_5E5
_ESR_STATUS6_5E5_CAN_TX_FACTORY_ALIGN_STATUS_2TYPE.containing_type = _ESR_STATUS6_5E5
_ESR_STATUS6_5E5_CAN_TX_FACTORY_ALIGN_STATUS_1TYPE.containing_type = _ESR_STATUS6_5E5
_ESR_STATUS6_5E5_CAN_TX_RECOMMEND_UNCONVERGETYPE.containing_type = _ESR_STATUS6_5E5
_ESR_STATUS6_5E5_CAN_TX_SYSTEM_POWER_MODETYPE.containing_type = _ESR_STATUS6_5E5
_ESR_STATUS4_4E3.fields_by_name['can_tx_truck_target_det'].enum_type = _ESR_STATUS4_4E3_CAN_TX_TRUCK_TARGET_DETTYPE
_ESR_STATUS4_4E3.fields_by_name['can_tx_lr_only_grating_lobe_det'].enum_type = _ESR_STATUS4_4E3_CAN_TX_LR_ONLY_GRATING_LOBE_DETTYPE
_ESR_STATUS4_4E3.fields_by_name['can_tx_sidelobe_blockage'].enum_type = _ESR_STATUS4_4E3_CAN_TX_SIDELOBE_BLOCKAGETYPE
_ESR_STATUS4_4E3.fields_by_name['can_tx_partial_blockage'].enum_type = _ESR_STATUS4_4E3_CAN_TX_PARTIAL_BLOCKAGETYPE
_ESR_STATUS4_4E3.fields_by_name['can_tx_mr_lr_mode'].enum_type = _ESR_STATUS4_4E3_CAN_TX_MR_LR_MODETYPE
_ESR_STATUS4_4E3_CAN_TX_TRUCK_TARGET_DETTYPE.containing_type = _ESR_STATUS4_4E3
_ESR_STATUS4_4E3_CAN_TX_LR_ONLY_GRATING_LOBE_DETTYPE.containing_type = _ESR_STATUS4_4E3
_ESR_STATUS4_4E3_CAN_TX_SIDELOBE_BLOCKAGETYPE.containing_type = _ESR_STATUS4_4E3
_ESR_STATUS4_4E3_CAN_TX_PARTIAL_BLOCKAGETYPE.containing_type = _ESR_STATUS4_4E3
_ESR_STATUS4_4E3_CAN_TX_MR_LR_MODETYPE.containing_type = _ESR_STATUS4_4E3
_ESR_TRACKMOTIONPOWER_540_MOTIONPOWER.containing_type = _ESR_TRACKMOTIONPOWER_540
_ESR_TRACKMOTIONPOWER_540.fields_by_name['can_tx_track_motion_power'].message_type = _ESR_TRACKMOTIONPOWER_540_MOTIONPOWER
_ESR_TRACK01_500.fields_by_name['can_tx_track_grouping_changed'].enum_type = _ESR_TRACK01_500_CAN_TX_TRACK_GROUPING_CHANGEDTYPE
_ESR_TRACK01_500.fields_by_name['can_tx_track_oncoming'].enum_type = _ESR_TRACK01_500_CAN_TX_TRACK_ONCOMINGTYPE
_ESR_TRACK01_500.fields_by_name['can_tx_track_bridge_object'].enum_type = _ESR_TRACK01_500_CAN_TX_TRACK_BRIDGE_OBJECTTYPE
_ESR_TRACK01_500.fields_by_name['can_tx_track_status'].enum_type = _ESR_TRACK01_500_CAN_TX_TRACK_STATUSTYPE
_ESR_TRACK01_500.fields_by_name['can_tx_track_med_range_mode'].enum_type = _ESR_TRACK01_500_CAN_TX_TRACK_MED_RANGE_MODETYPE
_ESR_TRACK01_500_CAN_TX_TRACK_GROUPING_CHANGEDTYPE.containing_type = _ESR_TRACK01_500
_ESR_TRACK01_500_CAN_TX_TRACK_ONCOMINGTYPE.containing_type = _ESR_TRACK01_500
_ESR_TRACK01_500_CAN_TX_TRACK_BRIDGE_OBJECTTYPE.containing_type = _ESR_TRACK01_500
_ESR_TRACK01_500_CAN_TX_TRACK_STATUSTYPE.containing_type = _ESR_TRACK01_500
_ESR_TRACK01_500_CAN_TX_TRACK_MED_RANGE_MODETYPE.containing_type = _ESR_TRACK01_500
_VEHICLE2_4F1.fields_by_name['can_rx_mr_only_transmit'].enum_type = _VEHICLE2_4F1_CAN_RX_MR_ONLY_TRANSMITTYPE
_VEHICLE2_4F1.fields_by_name['can_rx_lr_only_transmit'].enum_type = _VEHICLE2_4F1_CAN_RX_LR_ONLY_TRANSMITTYPE
_VEHICLE2_4F1.fields_by_name['can_rx_clear_faults'].enum_type = _VEHICLE2_4F1_CAN_RX_CLEAR_FAULTSTYPE
_VEHICLE2_4F1.fields_by_name['can_rx_use_angle_misalignment'].enum_type = _VEHICLE2_4F1_CAN_RX_USE_ANGLE_MISALIGNMENTTYPE
_VEHICLE2_4F1.fields_by_name['can_rx_turn_signal_status'].enum_type = _VEHICLE2_4F1_CAN_RX_TURN_SIGNAL_STATUSTYPE
_VEHICLE2_4F1.fields_by_name['can_rx_blockage_disable'].enum_type = _VEHICLE2_4F1_CAN_RX_BLOCKAGE_DISABLETYPE
_VEHICLE2_4F1.fields_by_name['can_rx_vehicle_speed_validity'].enum_type = _VEHICLE2_4F1_CAN_RX_VEHICLE_SPEED_VALIDITYTYPE
_VEHICLE2_4F1.fields_by_name['can_rx_mmr_upside_down'].enum_type = _VEHICLE2_4F1_CAN_RX_MMR_UPSIDE_DOWNTYPE
_VEHICLE2_4F1.fields_by_name['can_rx_wiper_status'].enum_type = _VEHICLE2_4F1_CAN_RX_WIPER_STATUSTYPE
_VEHICLE2_4F1.fields_by_name['can_rx_raw_data_enable'].enum_type = _VEHICLE2_4F1_CAN_RX_RAW_DATA_ENABLETYPE
_VEHICLE2_4F1.fields_by_name['can_rx_radar_cmd_radiate'].enum_type = _VEHICLE2_4F1_CAN_RX_RADAR_CMD_RADIATETYPE
_VEHICLE2_4F1.fields_by_name['can_rx_grouping_mode'].enum_type = _VEHICLE2_4F1_CAN_RX_GROUPING_MODETYPE
_VEHICLE2_4F1_CAN_RX_MR_ONLY_TRANSMITTYPE.containing_type = _VEHICLE2_4F1
_VEHICLE2_4F1_CAN_RX_LR_ONLY_TRANSMITTYPE.containing_type = _VEHICLE2_4F1
_VEHICLE2_4F1_CAN_RX_CLEAR_FAULTSTYPE.containing_type = _VEHICLE2_4F1
_VEHICLE2_4F1_CAN_RX_USE_ANGLE_MISALIGNMENTTYPE.containing_type = _VEHICLE2_4F1
_VEHICLE2_4F1_CAN_RX_TURN_SIGNAL_STATUSTYPE.containing_type = _VEHICLE2_4F1
_VEHICLE2_4F1_CAN_RX_BLOCKAGE_DISABLETYPE.containing_type = _VEHICLE2_4F1
_VEHICLE2_4F1_CAN_RX_VEHICLE_SPEED_VALIDITYTYPE.containing_type = _VEHICLE2_4F1
_VEHICLE2_4F1_CAN_RX_MMR_UPSIDE_DOWNTYPE.containing_type = _VEHICLE2_4F1
_VEHICLE2_4F1_CAN_RX_WIPER_STATUSTYPE.containing_type = _VEHICLE2_4F1
_VEHICLE2_4F1_CAN_RX_RAW_DATA_ENABLETYPE.containing_type = _VEHICLE2_4F1
_VEHICLE2_4F1_CAN_RX_RADAR_CMD_RADIATETYPE.containing_type = _VEHICLE2_4F1
_VEHICLE2_4F1_CAN_RX_GROUPING_MODETYPE.containing_type = _VEHICLE2_4F1
_VEHICLE1_4F0.fields_by_name['can_rx_steering_angle_validity'].enum_type = _VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_VALIDITYTYPE
_VEHICLE1_4F0.fields_by_name['can_rx_steering_angle_sign'].enum_type = _VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_SIGNTYPE
_VEHICLE1_4F0.fields_by_name['can_rx_steering_angle_rate_sign'].enum_type = _VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_RATE_SIGNTYPE
_VEHICLE1_4F0.fields_by_name['can_rx_yaw_rate_validity'].enum_type = _VEHICLE1_4F0_CAN_RX_YAW_RATE_VALIDITYTYPE
_VEHICLE1_4F0.fields_by_name['can_rx_vehicle_speed_direction'].enum_type = _VEHICLE1_4F0_CAN_RX_VEHICLE_SPEED_DIRECTIONTYPE
_VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_VALIDITYTYPE.containing_type = _VEHICLE1_4F0
_VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_SIGNTYPE.containing_type = _VEHICLE1_4F0
_VEHICLE1_4F0_CAN_RX_STEERING_ANGLE_RATE_SIGNTYPE.containing_type = _VEHICLE1_4F0
_VEHICLE1_4F0_CAN_RX_YAW_RATE_VALIDITYTYPE.containing_type = _VEHICLE1_4F0
_VEHICLE1_4F0_CAN_RX_VEHICLE_SPEED_DIRECTIONTYPE.containing_type = _VEHICLE1_4F0
_ESR_SIM1_5C0.fields_by_name['can_rx_sim_track_id'].enum_type = _ESR_SIM1_5C0_CAN_RX_SIM_TRACK_IDTYPE
_ESR_SIM1_5C0.fields_by_name['can_rx_sim_status'].enum_type = _ESR_SIM1_5C0_CAN_RX_SIM_STATUSTYPE
_ESR_SIM1_5C0.fields_by_name['can_rx_sim_function'].enum_type = _ESR_SIM1_5C0_CAN_RX_SIM_FUNCTIONTYPE
_ESR_SIM1_5C0_CAN_RX_SIM_TRACK_IDTYPE.containing_type = _ESR_SIM1_5C0
_ESR_SIM1_5C0_CAN_RX_SIM_STATUSTYPE.containing_type = _ESR_SIM1_5C0
_ESR_SIM1_5C0_CAN_RX_SIM_FUNCTIONTYPE.containing_type = _ESR_SIM1_5C0
_ESR_STATUS2_4E1.fields_by_name['can_tx_raw_data_mode'].enum_type = _ESR_STATUS2_4E1_CAN_TX_RAW_DATA_MODETYPE
_ESR_STATUS2_4E1.fields_by_name['can_tx_range_perf_error'].enum_type = _ESR_STATUS2_4E1_CAN_TX_RANGE_PERF_ERRORTYPE
_ESR_STATUS2_4E1.fields_by_name['can_tx_overheat_error'].enum_type = _ESR_STATUS2_4E1_CAN_TX_OVERHEAT_ERRORTYPE
_ESR_STATUS2_4E1.fields_by_name['can_tx_internal_error'].enum_type = _ESR_STATUS2_4E1_CAN_TX_INTERNAL_ERRORTYPE
_ESR_STATUS2_4E1.fields_by_name['can_tx_grouping_mode'].enum_type = _ESR_STATUS2_4E1_CAN_TX_GROUPING_MODETYPE
_ESR_STATUS2_4E1.fields_by_name['can_tx_xcvr_operational'].enum_type = _ESR_STATUS2_4E1_CAN_TX_XCVR_OPERATIONALTYPE
_ESR_STATUS2_4E1_CAN_TX_RAW_DATA_MODETYPE.containing_type = _ESR_STATUS2_4E1
_ESR_STATUS2_4E1_CAN_TX_RANGE_PERF_ERRORTYPE.containing_type = _ESR_STATUS2_4E1
_ESR_STATUS2_4E1_CAN_TX_OVERHEAT_ERRORTYPE.containing_type = _ESR_STATUS2_4E1
_ESR_STATUS2_4E1_CAN_TX_INTERNAL_ERRORTYPE.containing_type = _ESR_STATUS2_4E1
_ESR_STATUS2_4E1_CAN_TX_GROUPING_MODETYPE.containing_type = _ESR_STATUS2_4E1
_ESR_STATUS2_4E1_CAN_TX_XCVR_OPERATIONALTYPE.containing_type = _ESR_STATUS2_4E1
_VEHICLE3_5F2.fields_by_name['can_rx_serv_align_type'].enum_type = _VEHICLE3_5F2_CAN_RX_SERV_ALIGN_TYPETYPE
_VEHICLE3_5F2.fields_by_name['can_rx_serv_align_enable'].enum_type = _VEHICLE3_5F2_CAN_RX_SERV_ALIGN_ENABLETYPE
_VEHICLE3_5F2.fields_by_name['can_rx_auto_align_converged'].enum_type = _VEHICLE3_5F2_CAN_RX_AUTO_ALIGN_CONVERGEDTYPE
_VEHICLE3_5F2.fields_by_name['can_rx_auto_align_disable'].enum_type = _VEHICLE3_5F2_CAN_RX_AUTO_ALIGN_DISABLETYPE
_VEHICLE3_5F2.fields_by_name['can_rx_wheel_slip'].enum_type = _VEHICLE3_5F2_CAN_RX_WHEEL_SLIPTYPE
_VEHICLE3_5F2.fields_by_name['can_rx_long_accel_validity'].enum_type = _VEHICLE3_5F2_CAN_RX_LONG_ACCEL_VALIDITYTYPE
_VEHICLE3_5F2.fields_by_name['can_rx_lat_accel_validity'].enum_type = _VEHICLE3_5F2_CAN_RX_LAT_ACCEL_VALIDITYTYPE
_VEHICLE3_5F2_CAN_RX_SERV_ALIGN_TYPETYPE.containing_type = _VEHICLE3_5F2
_VEHICLE3_5F2_CAN_RX_SERV_ALIGN_ENABLETYPE.containing_type = _VEHICLE3_5F2
_VEHICLE3_5F2_CAN_RX_AUTO_ALIGN_CONVERGEDTYPE.containing_type = _VEHICLE3_5F2
_VEHICLE3_5F2_CAN_RX_AUTO_ALIGN_DISABLETYPE.containing_type = _VEHICLE3_5F2
_VEHICLE3_5F2_CAN_RX_WHEEL_SLIPTYPE.containing_type = _VEHICLE3_5F2
_VEHICLE3_5F2_CAN_RX_LONG_ACCEL_VALIDITYTYPE.containing_type = _VEHICLE3_5F2
_VEHICLE3_5F2_CAN_RX_LAT_ACCEL_VALIDITYTYPE.containing_type = _VEHICLE3_5F2
_VEHICLE4_5F3.fields_by_name['can_rx_fac_align_cmd_2'].enum_type = _VEHICLE4_5F3_CAN_RX_FAC_ALIGN_CMD_2TYPE
_VEHICLE4_5F3.fields_by_name['can_rx_fac_align_cmd_1'].enum_type = _VEHICLE4_5F3_CAN_RX_FAC_ALIGN_CMD_1TYPE
_VEHICLE4_5F3_CAN_RX_FAC_ALIGN_CMD_2TYPE.containing_type = _VEHICLE4_5F3
_VEHICLE4_5F3_CAN_RX_FAC_ALIGN_CMD_1TYPE.containing_type = _VEHICLE4_5F3
_VEHICLE5_5F4.fields_by_name['can_rx_yaw_rate_bias_shift'].enum_type = _VEHICLE5_5F4_CAN_RX_YAW_RATE_BIAS_SHIFTTYPE
_VEHICLE5_5F4_CAN_RX_YAW_RATE_BIAS_SHIFTTYPE.containing_type = _VEHICLE5_5F4
_DELPHIESR.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_DELPHIESR.fields_by_name['esr_status9_5e8'].message_type = _ESR_STATUS9_5E8
_DELPHIESR.fields_by_name['esr_status6_5e5'].message_type = _ESR_STATUS6_5E5
_DELPHIESR.fields_by_name['esr_status5_5e4'].message_type = _ESR_STATUS5_5E4
_DELPHIESR.fields_by_name['esr_status3_4e2'].message_type = _ESR_STATUS3_4E2
_DELPHIESR.fields_by_name['esr_status4_4e3'].message_type = _ESR_STATUS4_4E3
_DELPHIESR.fields_by_name['esr_trackmotionpower_540'].message_type = _ESR_TRACKMOTIONPOWER_540
_DELPHIESR.fields_by_name['acm_inst_req_7e0'].message_type = _ACM_INST_REQ_7E0
_DELPHIESR.fields_by_name['esr_track01_500'].message_type = _ESR_TRACK01_500
_DELPHIESR.fields_by_name['esr_valid1_5d0'].message_type = _ESR_VALID1_5D0
_DELPHIESR.fields_by_name['esr_valid2_5d1'].message_type = _ESR_VALID2_5D1
_DELPHIESR.fields_by_name['acm_inst_resp_7e4'].message_type = _ACM_INST_RESP_7E4
_DELPHIESR.fields_by_name['vehicle2_4f1'].message_type = _VEHICLE2_4F1
_DELPHIESR.fields_by_name['vehicle1_4f0'].message_type = _VEHICLE1_4F0
_DELPHIESR.fields_by_name['esr_sim1_5c0'].message_type = _ESR_SIM1_5C0
_DELPHIESR.fields_by_name['esr_status1_4e0'].message_type = _ESR_STATUS1_4E0
_DELPHIESR.fields_by_name['esr_status2_4e1'].message_type = _ESR_STATUS2_4E1
_DELPHIESR.fields_by_name['esr_status8_5e7'].message_type = _ESR_STATUS8_5E7
_DELPHIESR.fields_by_name['esr_status7_5e6'].message_type = _ESR_STATUS7_5E6
_DELPHIESR.fields_by_name['vehicle3_5f2'].message_type = _VEHICLE3_5F2
_DELPHIESR.fields_by_name['vehicle4_5f3'].message_type = _VEHICLE4_5F3
_DELPHIESR.fields_by_name['vehicle5_5f4'].message_type = _VEHICLE5_5F4
_DELPHIESR.fields_by_name['vehicle6_5f5'].message_type = _VEHICLE6_5F5
DESCRIPTOR.message_types_by_name['Esr_status9_5e8'] = _ESR_STATUS9_5E8
DESCRIPTOR.message_types_by_name['Esr_status6_5e5'] = _ESR_STATUS6_5E5
DESCRIPTOR.message_types_by_name['Esr_status5_5e4'] = _ESR_STATUS5_5E4
DESCRIPTOR.message_types_by_name['Esr_status3_4e2'] = _ESR_STATUS3_4E2
DESCRIPTOR.message_types_by_name['Esr_status4_4e3'] = _ESR_STATUS4_4E3
DESCRIPTOR.message_types_by_name['Esr_trackmotionpower_540'] = _ESR_TRACKMOTIONPOWER_540
DESCRIPTOR.message_types_by_name['Acm_inst_req_7e0'] = _ACM_INST_REQ_7E0
DESCRIPTOR.message_types_by_name['Esr_track01_500'] = _ESR_TRACK01_500
DESCRIPTOR.message_types_by_name['Esr_valid1_5d0'] = _ESR_VALID1_5D0
DESCRIPTOR.message_types_by_name['Esr_valid2_5d1'] = _ESR_VALID2_5D1
DESCRIPTOR.message_types_by_name['Acm_inst_resp_7e4'] = _ACM_INST_RESP_7E4
DESCRIPTOR.message_types_by_name['Vehicle2_4f1'] = _VEHICLE2_4F1
DESCRIPTOR.message_types_by_name['Vehicle1_4f0'] = _VEHICLE1_4F0
DESCRIPTOR.message_types_by_name['Esr_sim1_5c0'] = _ESR_SIM1_5C0
DESCRIPTOR.message_types_by_name['Esr_status1_4e0'] = _ESR_STATUS1_4E0
DESCRIPTOR.message_types_by_name['Esr_status2_4e1'] = _ESR_STATUS2_4E1
DESCRIPTOR.message_types_by_name['Esr_status8_5e7'] = _ESR_STATUS8_5E7
DESCRIPTOR.message_types_by_name['Esr_status7_5e6'] = _ESR_STATUS7_5E6
DESCRIPTOR.message_types_by_name['Vehicle3_5f2'] = _VEHICLE3_5F2
DESCRIPTOR.message_types_by_name['Vehicle4_5f3'] = _VEHICLE4_5F3
DESCRIPTOR.message_types_by_name['Vehicle5_5f4'] = _VEHICLE5_5F4
DESCRIPTOR.message_types_by_name['Vehicle6_5f5'] = _VEHICLE6_5F5
DESCRIPTOR.message_types_by_name['DelphiESR'] = _DELPHIESR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Esr_status9_5e8 = _reflection.GeneratedProtocolMessageType('Esr_status9_5e8', (_message.Message,), {
  'DESCRIPTOR' : _ESR_STATUS9_5E8,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_status9_5e8)
  })
_sym_db.RegisterMessage(Esr_status9_5e8)

Esr_status6_5e5 = _reflection.GeneratedProtocolMessageType('Esr_status6_5e5', (_message.Message,), {
  'DESCRIPTOR' : _ESR_STATUS6_5E5,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_status6_5e5)
  })
_sym_db.RegisterMessage(Esr_status6_5e5)

Esr_status5_5e4 = _reflection.GeneratedProtocolMessageType('Esr_status5_5e4', (_message.Message,), {
  'DESCRIPTOR' : _ESR_STATUS5_5E4,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_status5_5e4)
  })
_sym_db.RegisterMessage(Esr_status5_5e4)

Esr_status3_4e2 = _reflection.GeneratedProtocolMessageType('Esr_status3_4e2', (_message.Message,), {
  'DESCRIPTOR' : _ESR_STATUS3_4E2,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_status3_4e2)
  })
_sym_db.RegisterMessage(Esr_status3_4e2)

Esr_status4_4e3 = _reflection.GeneratedProtocolMessageType('Esr_status4_4e3', (_message.Message,), {
  'DESCRIPTOR' : _ESR_STATUS4_4E3,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_status4_4e3)
  })
_sym_db.RegisterMessage(Esr_status4_4e3)

Esr_trackmotionpower_540 = _reflection.GeneratedProtocolMessageType('Esr_trackmotionpower_540', (_message.Message,), {

  'Motionpower' : _reflection.GeneratedProtocolMessageType('Motionpower', (_message.Message,), {
    'DESCRIPTOR' : _ESR_TRACKMOTIONPOWER_540_MOTIONPOWER,
    '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
    # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_trackmotionpower_540.Motionpower)
    })
  ,
  'DESCRIPTOR' : _ESR_TRACKMOTIONPOWER_540,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_trackmotionpower_540)
  })
_sym_db.RegisterMessage(Esr_trackmotionpower_540)
_sym_db.RegisterMessage(Esr_trackmotionpower_540.Motionpower)

Acm_inst_req_7e0 = _reflection.GeneratedProtocolMessageType('Acm_inst_req_7e0', (_message.Message,), {
  'DESCRIPTOR' : _ACM_INST_REQ_7E0,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Acm_inst_req_7e0)
  })
_sym_db.RegisterMessage(Acm_inst_req_7e0)

Esr_track01_500 = _reflection.GeneratedProtocolMessageType('Esr_track01_500', (_message.Message,), {
  'DESCRIPTOR' : _ESR_TRACK01_500,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_track01_500)
  })
_sym_db.RegisterMessage(Esr_track01_500)

Esr_valid1_5d0 = _reflection.GeneratedProtocolMessageType('Esr_valid1_5d0', (_message.Message,), {
  'DESCRIPTOR' : _ESR_VALID1_5D0,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_valid1_5d0)
  })
_sym_db.RegisterMessage(Esr_valid1_5d0)

Esr_valid2_5d1 = _reflection.GeneratedProtocolMessageType('Esr_valid2_5d1', (_message.Message,), {
  'DESCRIPTOR' : _ESR_VALID2_5D1,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_valid2_5d1)
  })
_sym_db.RegisterMessage(Esr_valid2_5d1)

Acm_inst_resp_7e4 = _reflection.GeneratedProtocolMessageType('Acm_inst_resp_7e4', (_message.Message,), {
  'DESCRIPTOR' : _ACM_INST_RESP_7E4,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Acm_inst_resp_7e4)
  })
_sym_db.RegisterMessage(Acm_inst_resp_7e4)

Vehicle2_4f1 = _reflection.GeneratedProtocolMessageType('Vehicle2_4f1', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLE2_4F1,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Vehicle2_4f1)
  })
_sym_db.RegisterMessage(Vehicle2_4f1)

Vehicle1_4f0 = _reflection.GeneratedProtocolMessageType('Vehicle1_4f0', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLE1_4F0,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Vehicle1_4f0)
  })
_sym_db.RegisterMessage(Vehicle1_4f0)

Esr_sim1_5c0 = _reflection.GeneratedProtocolMessageType('Esr_sim1_5c0', (_message.Message,), {
  'DESCRIPTOR' : _ESR_SIM1_5C0,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_sim1_5c0)
  })
_sym_db.RegisterMessage(Esr_sim1_5c0)

Esr_status1_4e0 = _reflection.GeneratedProtocolMessageType('Esr_status1_4e0', (_message.Message,), {
  'DESCRIPTOR' : _ESR_STATUS1_4E0,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_status1_4e0)
  })
_sym_db.RegisterMessage(Esr_status1_4e0)

Esr_status2_4e1 = _reflection.GeneratedProtocolMessageType('Esr_status2_4e1', (_message.Message,), {
  'DESCRIPTOR' : _ESR_STATUS2_4E1,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_status2_4e1)
  })
_sym_db.RegisterMessage(Esr_status2_4e1)

Esr_status8_5e7 = _reflection.GeneratedProtocolMessageType('Esr_status8_5e7', (_message.Message,), {
  'DESCRIPTOR' : _ESR_STATUS8_5E7,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_status8_5e7)
  })
_sym_db.RegisterMessage(Esr_status8_5e7)

Esr_status7_5e6 = _reflection.GeneratedProtocolMessageType('Esr_status7_5e6', (_message.Message,), {
  'DESCRIPTOR' : _ESR_STATUS7_5E6,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Esr_status7_5e6)
  })
_sym_db.RegisterMessage(Esr_status7_5e6)

Vehicle3_5f2 = _reflection.GeneratedProtocolMessageType('Vehicle3_5f2', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLE3_5F2,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Vehicle3_5f2)
  })
_sym_db.RegisterMessage(Vehicle3_5f2)

Vehicle4_5f3 = _reflection.GeneratedProtocolMessageType('Vehicle4_5f3', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLE4_5F3,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Vehicle4_5f3)
  })
_sym_db.RegisterMessage(Vehicle4_5f3)

Vehicle5_5f4 = _reflection.GeneratedProtocolMessageType('Vehicle5_5f4', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLE5_5F4,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Vehicle5_5f4)
  })
_sym_db.RegisterMessage(Vehicle5_5f4)

Vehicle6_5f5 = _reflection.GeneratedProtocolMessageType('Vehicle6_5f5', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLE6_5F5,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Vehicle6_5f5)
  })
_sym_db.RegisterMessage(Vehicle6_5f5)

DelphiESR = _reflection.GeneratedProtocolMessageType('DelphiESR', (_message.Message,), {
  'DESCRIPTOR' : _DELPHIESR,
  '__module__' : 'modules.drivers.proto.delphi_esr_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.DelphiESR)
  })
_sym_db.RegisterMessage(DelphiESR)


# @@protoc_insertion_point(module_scope)
